/* GomNode.c generated by valac 0.34.6, the Vala compiler
 * generated from GomNode.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: nil; c-basic-offset: 2; tab-width: 2 -*- */
/*
 *
 * Copyright (C) 2016  Daniel Espinosa <esodan@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Daniel Espinosa <esodan@gmail.com>
 */

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <gio/gio.h>
#include <glib/gi18n-lib.h>


#define GXML_TYPE_DOM_EVENT_TARGET (gxml_dom_event_target_get_type ())
#define GXML_DOM_EVENT_TARGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT_TARGET, GXmlDomEventTarget))
#define GXML_IS_DOM_EVENT_TARGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT_TARGET))
#define GXML_DOM_EVENT_TARGET_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT_TARGET, GXmlDomEventTargetIface))

typedef struct _GXmlDomEventTarget GXmlDomEventTarget;
typedef struct _GXmlDomEventTargetIface GXmlDomEventTargetIface;

#define GXML_TYPE_DOM_EVENT_LISTENER (gxml_dom_event_listener_get_type ())
#define GXML_DOM_EVENT_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT_LISTENER, GXmlDomEventListener))
#define GXML_IS_DOM_EVENT_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT_LISTENER))
#define GXML_DOM_EVENT_LISTENER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT_LISTENER, GXmlDomEventListenerIface))

typedef struct _GXmlDomEventListener GXmlDomEventListener;
typedef struct _GXmlDomEventListenerIface GXmlDomEventListenerIface;

#define GXML_TYPE_DOM_EVENT (gxml_dom_event_get_type ())
#define GXML_DOM_EVENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT, GXmlDomEvent))
#define GXML_IS_DOM_EVENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT))
#define GXML_DOM_EVENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT, GXmlDomEventIface))

typedef struct _GXmlDomEvent GXmlDomEvent;
typedef struct _GXmlDomEventIface GXmlDomEventIface;

#define GXML_TYPE_DOM_TIME_STAMP (gxml_dom_time_stamp_get_type ())
#define GXML_DOM_TIME_STAMP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStamp))
#define GXML_DOM_TIME_STAMP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStampClass))
#define GXML_IS_DOM_TIME_STAMP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TIME_STAMP))
#define GXML_IS_DOM_TIME_STAMP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_TIME_STAMP))
#define GXML_DOM_TIME_STAMP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStampClass))

typedef struct _GXmlDomTimeStamp GXmlDomTimeStamp;
typedef struct _GXmlDomTimeStampClass GXmlDomTimeStampClass;

#define GXML_DOM_EVENT_TYPE_PHASE (gxml_dom_event_phase_get_type ())

#define GXML_TYPE_DOM_NODE (gxml_dom_node_get_type ())
#define GXML_DOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE, GXmlDomNode))
#define GXML_IS_DOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE))
#define GXML_DOM_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE, GXmlDomNodeIface))

typedef struct _GXmlDomNode GXmlDomNode;
typedef struct _GXmlDomNodeIface GXmlDomNodeIface;

#define GXML_DOM_NODE_TYPE_DOCUMENT_POSITION (gxml_dom_node_document_position_get_type ())

#define GXML_DOM_NODE_TYPE_NODE_TYPE (gxml_dom_node_node_type_get_type ())

#define GXML_TYPE_DOM_PARENT_NODE (gxml_dom_parent_node_get_type ())
#define GXML_DOM_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_PARENT_NODE, GXmlDomParentNode))
#define GXML_IS_DOM_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_PARENT_NODE))
#define GXML_DOM_PARENT_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_PARENT_NODE, GXmlDomParentNodeIface))

typedef struct _GXmlDomParentNode GXmlDomParentNode;
typedef struct _GXmlDomParentNodeIface GXmlDomParentNodeIface;

#define GXML_TYPE_DOM_CHILD_NODE (gxml_dom_child_node_get_type ())
#define GXML_DOM_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_CHILD_NODE, GXmlDomChildNode))
#define GXML_IS_DOM_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_CHILD_NODE))
#define GXML_DOM_CHILD_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_CHILD_NODE, GXmlDomChildNodeIface))

typedef struct _GXmlDomChildNode GXmlDomChildNode;
typedef struct _GXmlDomChildNodeIface GXmlDomChildNodeIface;

#define GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE (gxml_dom_non_document_type_child_node_get_type ())
#define GXML_DOM_NON_DOCUMENT_TYPE_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE, GXmlDomNonDocumentTypeChildNode))
#define GXML_IS_DOM_NON_DOCUMENT_TYPE_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE))
#define GXML_DOM_NON_DOCUMENT_TYPE_CHILD_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE, GXmlDomNonDocumentTypeChildNodeIface))

typedef struct _GXmlDomNonDocumentTypeChildNode GXmlDomNonDocumentTypeChildNode;
typedef struct _GXmlDomNonDocumentTypeChildNodeIface GXmlDomNonDocumentTypeChildNodeIface;

#define GXML_TYPE_DOM_ELEMENT (gxml_dom_element_get_type ())
#define GXML_DOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_ELEMENT, GXmlDomElement))
#define GXML_IS_DOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_ELEMENT))
#define GXML_DOM_ELEMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_ELEMENT, GXmlDomElementIface))

typedef struct _GXmlDomElement GXmlDomElement;
typedef struct _GXmlDomElementIface GXmlDomElementIface;

#define GXML_TYPE_DOM_HTML_COLLECTION (gxml_dom_html_collection_get_type ())
#define GXML_DOM_HTML_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_HTML_COLLECTION, GXmlDomHTMLCollection))
#define GXML_IS_DOM_HTML_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_HTML_COLLECTION))
#define GXML_DOM_HTML_COLLECTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_HTML_COLLECTION, GXmlDomHTMLCollectionIface))

typedef struct _GXmlDomHTMLCollection GXmlDomHTMLCollection;
typedef struct _GXmlDomHTMLCollectionIface GXmlDomHTMLCollectionIface;

#define GXML_TYPE_DOM_TOKEN_LIST (gxml_dom_token_list_get_type ())
#define GXML_DOM_TOKEN_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TOKEN_LIST, GXmlDomTokenList))
#define GXML_IS_DOM_TOKEN_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TOKEN_LIST))
#define GXML_DOM_TOKEN_LIST_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TOKEN_LIST, GXmlDomTokenListIface))

typedef struct _GXmlDomTokenList GXmlDomTokenList;
typedef struct _GXmlDomTokenListIface GXmlDomTokenListIface;

#define GXML_TYPE_DOM_NAMED_NODE_MAP (gxml_dom_named_node_map_get_type ())
#define GXML_DOM_NAMED_NODE_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP, GXmlDomNamedNodeMap))
#define GXML_IS_DOM_NAMED_NODE_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP))
#define GXML_DOM_NAMED_NODE_MAP_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP, GXmlDomNamedNodeMapIface))

typedef struct _GXmlDomNamedNodeMap GXmlDomNamedNodeMap;
typedef struct _GXmlDomNamedNodeMapIface GXmlDomNamedNodeMapIface;

#define GXML_TYPE_DOM_NODE_LIST (gxml_dom_node_list_get_type ())
#define GXML_DOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_LIST, GXmlDomNodeList))
#define GXML_IS_DOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_LIST))
#define GXML_DOM_NODE_LIST_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE_LIST, GXmlDomNodeListIface))

typedef struct _GXmlDomNodeList GXmlDomNodeList;
typedef struct _GXmlDomNodeListIface GXmlDomNodeListIface;

#define GXML_TYPE_DOM_ELEMENT_LIST (gxml_dom_element_list_get_type ())
#define GXML_DOM_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementList))
#define GXML_DOM_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementListClass))
#define GXML_IS_DOM_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_ELEMENT_LIST))
#define GXML_IS_DOM_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_ELEMENT_LIST))
#define GXML_DOM_ELEMENT_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementListClass))

typedef struct _GXmlDomElementList GXmlDomElementList;
typedef struct _GXmlDomElementListClass GXmlDomElementListClass;

#define GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE (gxml_dom_non_element_parent_node_get_type ())
#define GXML_DOM_NON_ELEMENT_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE, GXmlDomNonElementParentNode))
#define GXML_IS_DOM_NON_ELEMENT_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE))
#define GXML_DOM_NON_ELEMENT_PARENT_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE, GXmlDomNonElementParentNodeIface))

typedef struct _GXmlDomNonElementParentNode GXmlDomNonElementParentNode;
typedef struct _GXmlDomNonElementParentNodeIface GXmlDomNonElementParentNodeIface;

#define GXML_TYPE_DOM_DOCUMENT (gxml_dom_document_get_type ())
#define GXML_DOM_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT, GXmlDomDocument))
#define GXML_IS_DOM_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT))
#define GXML_DOM_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT, GXmlDomDocumentIface))

typedef struct _GXmlDomDocument GXmlDomDocument;
typedef struct _GXmlDomDocumentIface GXmlDomDocumentIface;

#define GXML_TYPE_DOM_DOCUMENT_FRAGMENT (gxml_dom_document_fragment_get_type ())
#define GXML_DOM_DOCUMENT_FRAGMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT, GXmlDomDocumentFragment))
#define GXML_IS_DOM_DOCUMENT_FRAGMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT))
#define GXML_DOM_DOCUMENT_FRAGMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT, GXmlDomDocumentFragmentIface))

typedef struct _GXmlDomDocumentFragment GXmlDomDocumentFragment;
typedef struct _GXmlDomDocumentFragmentIface GXmlDomDocumentFragmentIface;

#define GXML_TYPE_DOM_CHARACTER_DATA (gxml_dom_character_data_get_type ())
#define GXML_DOM_CHARACTER_DATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_CHARACTER_DATA, GXmlDomCharacterData))
#define GXML_IS_DOM_CHARACTER_DATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_CHARACTER_DATA))
#define GXML_DOM_CHARACTER_DATA_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_CHARACTER_DATA, GXmlDomCharacterDataIface))

typedef struct _GXmlDomCharacterData GXmlDomCharacterData;
typedef struct _GXmlDomCharacterDataIface GXmlDomCharacterDataIface;

#define GXML_TYPE_DOM_TEXT (gxml_dom_text_get_type ())
#define GXML_DOM_TEXT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TEXT, GXmlDomText))
#define GXML_IS_DOM_TEXT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TEXT))
#define GXML_DOM_TEXT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TEXT, GXmlDomTextIface))

typedef struct _GXmlDomText GXmlDomText;
typedef struct _GXmlDomTextIface GXmlDomTextIface;

#define GXML_TYPE_DOM_COMMENT (gxml_dom_comment_get_type ())
#define GXML_DOM_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_COMMENT, GXmlDomComment))
#define GXML_IS_DOM_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_COMMENT))
#define GXML_DOM_COMMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_COMMENT, GXmlDomCommentIface))

typedef struct _GXmlDomComment GXmlDomComment;
typedef struct _GXmlDomCommentIface GXmlDomCommentIface;

#define GXML_TYPE_DOM_PROCESSING_INSTRUCTION (gxml_dom_processing_instruction_get_type ())
#define GXML_DOM_PROCESSING_INSTRUCTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION, GXmlDomProcessingInstruction))
#define GXML_IS_DOM_PROCESSING_INSTRUCTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION))
#define GXML_DOM_PROCESSING_INSTRUCTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION, GXmlDomProcessingInstructionIface))

typedef struct _GXmlDomProcessingInstruction GXmlDomProcessingInstruction;
typedef struct _GXmlDomProcessingInstructionIface GXmlDomProcessingInstructionIface;

#define GXML_TYPE_DOM_RANGE (gxml_dom_range_get_type ())
#define GXML_DOM_RANGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_RANGE, GXmlDomRange))
#define GXML_IS_DOM_RANGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_RANGE))
#define GXML_DOM_RANGE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_RANGE, GXmlDomRangeIface))

typedef struct _GXmlDomRange GXmlDomRange;
typedef struct _GXmlDomRangeIface GXmlDomRangeIface;

#define GXML_DOM_RANGE_TYPE_BOUNDARY_POINTS (gxml_dom_range_boundary_points_get_type ())

#define GXML_TYPE_DOM_NODE_FILTER (gxml_dom_node_filter_get_type ())
#define GXML_DOM_NODE_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilter))
#define GXML_DOM_NODE_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilterClass))
#define GXML_IS_DOM_NODE_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_FILTER))
#define GXML_IS_DOM_NODE_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_NODE_FILTER))
#define GXML_DOM_NODE_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilterClass))

typedef struct _GXmlDomNodeFilter GXmlDomNodeFilter;
typedef struct _GXmlDomNodeFilterClass GXmlDomNodeFilterClass;

#define GXML_TYPE_DOM_NODE_ITERATOR (gxml_dom_node_iterator_get_type ())
#define GXML_DOM_NODE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_ITERATOR, GXmlDomNodeIterator))
#define GXML_IS_DOM_NODE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_ITERATOR))
#define GXML_DOM_NODE_ITERATOR_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE_ITERATOR, GXmlDomNodeIteratorIface))

typedef struct _GXmlDomNodeIterator GXmlDomNodeIterator;
typedef struct _GXmlDomNodeIteratorIface GXmlDomNodeIteratorIface;

#define GXML_TYPE_DOM_TREE_WALKER (gxml_dom_tree_walker_get_type ())
#define GXML_DOM_TREE_WALKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TREE_WALKER, GXmlDomTreeWalker))
#define GXML_IS_DOM_TREE_WALKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TREE_WALKER))
#define GXML_DOM_TREE_WALKER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TREE_WALKER, GXmlDomTreeWalkerIface))

typedef struct _GXmlDomTreeWalker GXmlDomTreeWalker;
typedef struct _GXmlDomTreeWalkerIface GXmlDomTreeWalkerIface;

#define GXML_TYPE_DOM_IMPLEMENTATION (gxml_dom_implementation_get_type ())
#define GXML_DOM_IMPLEMENTATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_IMPLEMENTATION, GXmlDomImplementation))
#define GXML_IS_DOM_IMPLEMENTATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_IMPLEMENTATION))
#define GXML_DOM_IMPLEMENTATION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_IMPLEMENTATION, GXmlDomImplementationIface))

typedef struct _GXmlDomImplementation GXmlDomImplementation;
typedef struct _GXmlDomImplementationIface GXmlDomImplementationIface;

#define GXML_TYPE_DOM_DOCUMENT_TYPE (gxml_dom_document_type_get_type ())
#define GXML_DOM_DOCUMENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE, GXmlDomDocumentType))
#define GXML_IS_DOM_DOCUMENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE))
#define GXML_DOM_DOCUMENT_TYPE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE, GXmlDomDocumentTypeIface))

typedef struct _GXmlDomDocumentType GXmlDomDocumentType;
typedef struct _GXmlDomDocumentTypeIface GXmlDomDocumentTypeIface;

#define GXML_TYPE_DOM_XML_DOCUMENT (gxml_dom_xml_document_get_type ())
#define GXML_DOM_XML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_XML_DOCUMENT, GXmlDomXMLDocument))
#define GXML_IS_DOM_XML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_XML_DOCUMENT))
#define GXML_DOM_XML_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_XML_DOCUMENT, GXmlDomXMLDocumentIface))

typedef struct _GXmlDomXMLDocument GXmlDomXMLDocument;
typedef struct _GXmlDomXMLDocumentIface GXmlDomXMLDocumentIface;

#define GXML_TYPE_NODE (gxml_node_get_type ())
#define GXML_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_NODE, GXmlNode))
#define GXML_IS_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_NODE))
#define GXML_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_NODE, GXmlNodeIface))

typedef struct _GXmlNode GXmlNode;
typedef struct _GXmlNodeIface GXmlNodeIface;

#define GXML_TYPE_ELEMENT_LIST (gxml_element_list_get_type ())
#define GXML_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_ELEMENT_LIST, GXmlElementList))
#define GXML_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_ELEMENT_LIST, GXmlElementListClass))
#define GXML_IS_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_ELEMENT_LIST))
#define GXML_IS_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_ELEMENT_LIST))
#define GXML_ELEMENT_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_ELEMENT_LIST, GXmlElementListClass))

typedef struct _GXmlElementList GXmlElementList;
typedef struct _GXmlElementListClass GXmlElementListClass;

#define GXML_TYPE_NAMESPACE (gxml_namespace_get_type ())
#define GXML_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_NAMESPACE, GXmlNamespace))
#define GXML_IS_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_NAMESPACE))
#define GXML_NAMESPACE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_NAMESPACE, GXmlNamespaceIface))

typedef struct _GXmlNamespace GXmlNamespace;
typedef struct _GXmlNamespaceIface GXmlNamespaceIface;

#define GXML_TYPE_NODE_TYPE (gxml_node_type_get_type ())

#define GXML_TYPE_DOCUMENT (gxml_document_get_type ())
#define GXML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOCUMENT, GXmlDocument))
#define GXML_IS_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOCUMENT))
#define GXML_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOCUMENT, GXmlDocumentIface))

typedef struct _GXmlDocument GXmlDocument;
typedef struct _GXmlDocumentIface GXmlDocumentIface;

#define GXML_TYPE_GOM_NODE (gxml_gom_node_get_type ())
#define GXML_GOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_NODE, GXmlGomNode))
#define GXML_GOM_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_NODE, GXmlGomNodeClass))
#define GXML_IS_GOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_NODE))
#define GXML_IS_GOM_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_NODE))
#define GXML_GOM_NODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_NODE, GXmlGomNodeClass))

typedef struct _GXmlGomNode GXmlGomNode;
typedef struct _GXmlGomNodeClass GXmlGomNodeClass;
typedef struct _GXmlGomNodePrivate GXmlGomNodePrivate;

#define GXML_TYPE_GOM_NODE_LIST (gxml_gom_node_list_get_type ())
#define GXML_GOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_NODE_LIST, GXmlGomNodeList))
#define GXML_GOM_NODE_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_NODE_LIST, GXmlGomNodeListClass))
#define GXML_IS_GOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_NODE_LIST))
#define GXML_IS_GOM_NODE_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_NODE_LIST))
#define GXML_GOM_NODE_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_NODE_LIST, GXmlGomNodeListClass))

typedef struct _GXmlGomNodeList GXmlGomNodeList;
typedef struct _GXmlGomNodeListClass GXmlGomNodeListClass;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define GXML_TYPE_GOM_ELEMENT (gxml_gom_element_get_type ())
#define GXML_GOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_ELEMENT, GXmlGomElement))
#define GXML_GOM_ELEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_ELEMENT, GXmlGomElementClass))
#define GXML_IS_GOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_ELEMENT))
#define GXML_IS_GOM_ELEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_ELEMENT))
#define GXML_GOM_ELEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_ELEMENT, GXmlGomElementClass))

typedef struct _GXmlGomElement GXmlGomElement;
typedef struct _GXmlGomElementClass GXmlGomElementClass;

#define GXML_TYPE_DOM_ATTR (gxml_dom_attr_get_type ())
#define GXML_DOM_ATTR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_ATTR, GXmlDomAttr))
#define GXML_IS_DOM_ATTR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_ATTR))
#define GXML_DOM_ATTR_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_ATTR, GXmlDomAttrIface))

typedef struct _GXmlDomAttr GXmlDomAttr;
typedef struct _GXmlDomAttrIface GXmlDomAttrIface;

#define GXML_TYPE_GNODE (gxml_gnode_get_type ())
#define GXML_GNODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GNODE, GXmlGNode))
#define GXML_GNODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GNODE, GXmlGNodeClass))
#define GXML_IS_GNODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GNODE))
#define GXML_IS_GNODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GNODE))
#define GXML_GNODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GNODE, GXmlGNodeClass))

typedef struct _GXmlGNode GXmlGNode;
typedef struct _GXmlGNodeClass GXmlGNodeClass;

#define GXML_TYPE_GOM_DOCUMENT (gxml_gom_document_get_type ())
#define GXML_GOM_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_DOCUMENT, GXmlGomDocument))
#define GXML_GOM_DOCUMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_DOCUMENT, GXmlGomDocumentClass))
#define GXML_IS_GOM_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_DOCUMENT))
#define GXML_IS_GOM_DOCUMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_DOCUMENT))
#define GXML_GOM_DOCUMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_DOCUMENT, GXmlGomDocumentClass))

typedef struct _GXmlGomDocument GXmlGomDocument;
typedef struct _GXmlGomDocumentClass GXmlGomDocumentClass;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _GXmlGomNodeListPrivate GXmlGomNodeListPrivate;

typedef enum  {
	GXML_DOM_EVENT_PHASE_NONE = 0,
	GXML_DOM_EVENT_PHASE_CAPTURING_PHASE,
	GXML_DOM_EVENT_PHASE_AT_TARGET,
	GXML_DOM_EVENT_PHASE_BUBBLING_PHASE
} GXmlDomEventPhase;

struct _GXmlDomEventIface {
	GTypeInterface parent_iface;
	void (*stop_propagation) (GXmlDomEvent* self);
	void (*stop_immediate_propagation) (GXmlDomEvent* self);
	void (*prevent_default) (GXmlDomEvent* self);
	void (*init_event) (GXmlDomEvent* self, const gchar* type, gboolean bubbles, gboolean cancelable);
	const gchar* (*get_etype) (GXmlDomEvent* self);
	GXmlDomEventTarget* (*get_event_target) (GXmlDomEvent* self);
	GXmlDomEventTarget* (*get_current_target) (GXmlDomEvent* self);
	gboolean (*get_bubbles) (GXmlDomEvent* self);
	gboolean (*get_cancelable) (GXmlDomEvent* self);
	gboolean (*get_is_trusted) (GXmlDomEvent* self);
	GXmlDomTimeStamp* (*get_time_stamp) (GXmlDomEvent* self);
	gboolean (*get_default_prevented) (GXmlDomEvent* self);
	GXmlDomEventPhase (*get_event_phase) (GXmlDomEvent* self);
};

struct _GXmlDomEventListenerIface {
	GTypeInterface parent_iface;
	void (*handle_event) (GXmlDomEventListener* self, GXmlDomEvent* event);
};

struct _GXmlDomEventTargetIface {
	GTypeInterface parent_iface;
	void (*add_event_listener) (GXmlDomEventTarget* self, const gchar* type, GXmlDomEventListener* callback, gboolean capture);
	void (*remove_event_listener) (GXmlDomEventTarget* self, const gchar* type, GXmlDomEventListener* callback, gboolean capture);
	gboolean (*dispatch_event) (GXmlDomEventTarget* self, GXmlDomEvent* event, GError** error);
};

typedef enum  {
	GXML_DOM_NODE_DOCUMENT_POSITION_NONE = 1 << 0,
	GXML_DOM_NODE_DOCUMENT_POSITION_DISCONNECTED = 1 << 1,
	GXML_DOM_NODE_DOCUMENT_POSITION_PRECEDING = 1 << 2,
	GXML_DOM_NODE_DOCUMENT_POSITION_FOLLOWING = 1 << 3,
	GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINS = 1 << 4,
	GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINED_BY = 1 << 5,
	GXML_DOM_NODE_DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC = 1 << 6
} GXmlDomNodeDocumentPosition;

typedef enum  {
	GXML_DOM_NODE_NODE_TYPE_INVALID = 0,
	GXML_DOM_NODE_NODE_TYPE_ELEMENT_NODE = 1,
	GXML_DOM_NODE_NODE_TYPE_ATTRIBUTE_NODE,
	GXML_DOM_NODE_NODE_TYPE_TEXT_NODE,
	GXML_DOM_NODE_NODE_TYPE_CDATA_SECTION_NODE,
	GXML_DOM_NODE_NODE_TYPE_ENTITY_REFERENCE_NODE,
	GXML_DOM_NODE_NODE_TYPE_ENTITY_NODE,
	GXML_DOM_NODE_NODE_TYPE_PROCESSING_INSTRUCTION_NODE,
	GXML_DOM_NODE_NODE_TYPE_COMMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_TYPE_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_FRAGMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_NOTATION_NODE
} GXmlDomNodeNodeType;

struct _GXmlDomChildNodeIface {
	GTypeInterface parent_iface;
	void (*remove) (GXmlDomChildNode* self);
};

struct _GXmlDomNonDocumentTypeChildNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_previous_element_sibling) (GXmlDomNonDocumentTypeChildNode* self);
	GXmlDomElement* (*get_next_element_sibling) (GXmlDomNonDocumentTypeChildNode* self);
};

struct _GXmlDomHTMLCollectionIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_element) (GXmlDomHTMLCollection* self, gint index);
	GXmlDomElement** (*to_array) (GXmlDomHTMLCollection* self, int* result_length1);
	GXmlDomElement* (*item) (GXmlDomHTMLCollection* self, gint index);
	GXmlDomElement* (*named_item) (GXmlDomHTMLCollection* self, const gchar* name);
	gint (*get_length) (GXmlDomHTMLCollection* self);
};

struct _GXmlDomTokenListIface {
	GTypeInterface parent_iface;
	gchar* (*item) (GXmlDomTokenList* self, gint index);
	gboolean (*contains) (GXmlDomTokenList* self, const gchar* token, GError** error);
	void (*add) (GXmlDomTokenList* self, gchar** tokens, int tokens_length1, GError** error);
	void (*remove) (GXmlDomTokenList* self, gchar** tokens, int tokens_length1);
	gboolean (*toggle) (GXmlDomTokenList* self, const gchar* token, gboolean force, gboolean _auto_, GError** error);
	gchar* (*to_string) (GXmlDomTokenList* self);
	gint (*get_length) (GXmlDomTokenList* self);
};

struct _GXmlDomNamedNodeMapIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*item) (GXmlDomNamedNodeMap* self, gint index);
	GXmlDomNode* (*get_named_item) (GXmlDomNamedNodeMap* self, const gchar* name);
	GXmlDomNode* (*set_named_item) (GXmlDomNamedNodeMap* self, GXmlDomNode* node, GError** error);
	GXmlDomNode* (*remove_named_item) (GXmlDomNamedNodeMap* self, const gchar* name, GError** error);
	GXmlDomNode* (*remove_named_item_ns) (GXmlDomNamedNodeMap* self, const gchar* namespace_uri, const gchar* localName, GError** error);
	GXmlDomNode* (*get_named_item_ns) (GXmlDomNamedNodeMap* self, const gchar* namespace_uri, const gchar* local_name, GError** error);
	GXmlDomNode* (*set_named_item_ns) (GXmlDomNamedNodeMap* self, GXmlDomNode* node, GError** error);
	gint (*get_length) (GXmlDomNamedNodeMap* self);
};

struct _GXmlDomElementIface {
	GTypeInterface parent_iface;
	gchar* (*get_attribute) (GXmlDomElement* self, const gchar* name);
	gchar* (*get_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	void (*set_attribute) (GXmlDomElement* self, const gchar* name, const gchar* value, GError** error);
	void (*set_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* name, const gchar* value, GError** error);
	void (*remove_attribute) (GXmlDomElement* self, const gchar* name);
	void (*remove_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	gboolean (*has_attribute) (GXmlDomElement* self, const gchar* name);
	gboolean (*has_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name) (GXmlDomElement* self, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_class_name) (GXmlDomElement* self, const gchar* class_names);
	gchar* (*get_namespace_uri) (GXmlDomElement* self);
	gchar* (*get_prefix) (GXmlDomElement* self);
	gchar* (*get_local_name) (GXmlDomElement* self);
	gchar* (*get_tag_name) (GXmlDomElement* self);
	gchar* (*get_id) (GXmlDomElement* self);
	void (*set_id) (GXmlDomElement* self, const gchar* value);
	gchar* (*get_class_name) (GXmlDomElement* self);
	void (*set_class_name) (GXmlDomElement* self, const gchar* value);
	GXmlDomTokenList* (*get_class_list) (GXmlDomElement* self);
	GXmlDomNamedNodeMap* (*get_attributes) (GXmlDomElement* self);
};

struct _GXmlDomNodeListIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*item) (GXmlDomNodeList* self, gint index);
	gint (*get_length) (GXmlDomNodeList* self);
};

struct _GXmlDomParentNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*query_selector) (GXmlDomParentNode* self, const gchar* selectors, GError** error);
	GXmlDomNodeList* (*query_selector_all) (GXmlDomParentNode* self, const gchar* selectors, GError** error);
	GXmlDomElementList* (*get_elements_by_property_value) (GXmlDomParentNode* self, const gchar* property, const gchar* value);
	GXmlDomHTMLCollection* (*get_children) (GXmlDomParentNode* self);
	GXmlDomElement* (*get_first_element_child) (GXmlDomParentNode* self);
	GXmlDomElement* (*get_last_element_child) (GXmlDomParentNode* self);
	gint (*get_child_element_count) (GXmlDomParentNode* self);
};

struct _GXmlDomNonElementParentNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_element_by_id) (GXmlDomNonElementParentNode* self, const gchar* element_id, GError** error);
};

struct _GXmlDomDocumentFragmentIface {
	GTypeInterface parent_iface;
};

struct _GXmlDomCharacterDataIface {
	GTypeInterface parent_iface;
	gchar* (*substring_data) (GXmlDomCharacterData* self, gint offset, gint count, GError** error);
	void (*append_data) (GXmlDomCharacterData* self, const gchar* data);
	void (*insert_data) (GXmlDomCharacterData* self, gint offset, const gchar* data, GError** error);
	void (*delete_data) (GXmlDomCharacterData* self, gint offset, gint count, GError** error);
	void (*replace_data) (GXmlDomCharacterData* self, gint offset, gint count, const gchar* data, GError** error);
	gchar* (*get_data) (GXmlDomCharacterData* self);
	void (*set_data) (GXmlDomCharacterData* self, const gchar* value);
	gint (*get_length) (GXmlDomCharacterData* self);
};

struct _GXmlDomTextIface {
	GTypeInterface parent_iface;
	GXmlDomText* (*split_text) (GXmlDomText* self, gint offset, GError** error);
	gchar* (*get_whole_text) (GXmlDomText* self);
};

struct _GXmlDomCommentIface {
	GTypeInterface parent_iface;
};

struct _GXmlDomProcessingInstructionIface {
	GTypeInterface parent_iface;
	gchar* (*get_target) (GXmlDomProcessingInstruction* self);
};

typedef enum  {
	GXML_DOM_RANGE_BOUNDARY_POINTS_START_TO_START = 0,
	GXML_DOM_RANGE_BOUNDARY_POINTS_START_TO_END,
	GXML_DOM_RANGE_BOUNDARY_POINTS_END_TO_END,
	GXML_DOM_RANGE_BOUNDARY_POINTS_END_TO_START
} GXmlDomRangeBoundaryPoints;

struct _GXmlDomRangeIface {
	GTypeInterface parent_iface;
	void (*set_start) (GXmlDomRange* self, GXmlDomNode* node, gint offset, GError** error);
	void (*set_end) (GXmlDomRange* self, GXmlDomNode* node, gint offset, GError** error);
	void (*set_start_before) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_start_after) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_end_before) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_end_after) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*collapse) (GXmlDomRange* self, gboolean to_start, GError** error);
	void (*select_node) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*select_node_contents) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	gint (*compare_boundary_points) (GXmlDomRange* self, GXmlDomRangeBoundaryPoints how, GXmlDomRange* sourceRange, GError** error);
	void (*delete_contents) (GXmlDomRange* self, GError** error);
	GXmlDomDocumentFragment* (*extract_contents) (GXmlDomRange* self, GError** error);
	GXmlDomDocumentFragment* (*clone_contents) (GXmlDomRange* self, GError** error);
	void (*insert_node) (GXmlDomRange* self, GXmlDomNode* node);
	void (*surround_contents) (GXmlDomRange* self, GXmlDomNode* newParent);
	GXmlDomRange* (*clone_range) (GXmlDomRange* self);
	void (*detach) (GXmlDomRange* self);
	gboolean (*is_point_in_range) (GXmlDomRange* self, GXmlDomNode* node, gint offset);
	gshort (*compare_point) (GXmlDomRange* self, GXmlDomNode* node, gint offset);
	gboolean (*intersects_node) (GXmlDomRange* self, GXmlDomNode* node);
	gchar* (*to_string) (GXmlDomRange* self);
	GXmlDomNode* (*get_start_container) (GXmlDomRange* self);
	gint (*get_start_offset) (GXmlDomRange* self);
	GXmlDomNode* (*get_end_container) (GXmlDomRange* self);
	gint (*get_end_offset) (GXmlDomRange* self);
	gboolean (*get_collapsed) (GXmlDomRange* self);
	GXmlDomNode* (*get_common_ancestor_container) (GXmlDomRange* self);
};

struct _GXmlDomNodeIteratorIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*next_node) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*previous_node) (GXmlDomNodeIterator* self);
	void (*detach) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*get_root) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*get_reference_node) (GXmlDomNodeIterator* self);
	gboolean (*get_pointer_before_reference_node) (GXmlDomNodeIterator* self);
	gint (*get_what_to_show) (GXmlDomNodeIterator* self);
	GXmlDomNodeFilter* (*get_filter) (GXmlDomNodeIterator* self);
};

struct _GXmlDomTreeWalkerIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*parentNode) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*firstChild) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*lastChild) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*previousSibling) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*nextSibling) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*previousNode) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*nextNode) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*get_root) (GXmlDomTreeWalker* self);
	gint (*get_what_to_show) (GXmlDomTreeWalker* self);
	GXmlDomNodeFilter* (*get_filter) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*get_current_node) (GXmlDomTreeWalker* self);
};

struct _GXmlDomDocumentTypeIface {
	GTypeInterface parent_iface;
	const gchar* (*get_name) (GXmlDomDocumentType* self);
	const gchar* (*get_public_id) (GXmlDomDocumentType* self);
	const gchar* (*get_system_id) (GXmlDomDocumentType* self);
};

struct _GXmlDomXMLDocumentIface {
	GTypeInterface parent_iface;
};

struct _GXmlNamespaceIface {
	GTypeInterface parent_iface;
	gchar* (*get_uri) (GXmlNamespace* self);
	gchar* (*get_prefix) (GXmlNamespace* self);
};

typedef enum  {
	GXML_NODE_TYPE_INVALID = 0,
	GXML_NODE_TYPE_ELEMENT = 1,
	GXML_NODE_TYPE_ATTRIBUTE,
	GXML_NODE_TYPE_TEXT,
	GXML_NODE_TYPE_CDATA_SECTION,
	GXML_NODE_TYPE_ENTITY_REFERENCE,
	GXML_NODE_TYPE_ENTITY,
	GXML_NODE_TYPE_PROCESSING_INSTRUCTION,
	GXML_NODE_TYPE_COMMENT,
	GXML_NODE_TYPE_DOCUMENT,
	GXML_NODE_TYPE_DOCUMENT_TYPE,
	GXML_NODE_TYPE_DOCUMENT_FRAGMENT,
	GXML_NODE_TYPE_NOTATION
} GXmlNodeType;

struct _GXmlNodeIface {
	GTypeInterface parent_iface;
	GXmlNode* (*get) (GXmlNode* self, const gchar* key);
	GXmlElementList* (*get_elements_by_property_value) (GXmlNode* self, const gchar* property, const gchar* value);
	GXmlElementList* (*get_elements_by_name) (GXmlNode* self, const gchar* name);
	GXmlElementList* (*get_elements_by_name_ns) (GXmlNode* self, const gchar* name, const gchar* ns);
	gchar* (*to_string) (GXmlNode* self);
	gboolean (*set_namespace) (GXmlNode* self, const gchar* uri, const gchar* prefix);
	gchar* (*ns_prefix) (GXmlNode* self);
	gchar* (*ns_uri) (GXmlNode* self);
	GeeList* (*get_namespaces) (GXmlNode* self);
	GeeBidirList* (*get_children_nodes) (GXmlNode* self);
	GeeMap* (*get_attrs) (GXmlNode* self);
	gchar* (*get_name) (GXmlNode* self);
	gchar* (*get_value) (GXmlNode* self);
	void (*set_value) (GXmlNode* self, const gchar* value);
	GXmlNodeType (*get_type_node) (GXmlNode* self);
	GXmlDocument* (*get_document) (GXmlNode* self);
	GXmlNode* (*get_parent) (GXmlNode* self);
};

struct _GXmlDocumentIface {
	GTypeInterface parent_iface;
	GXmlNode* (*create_element) (GXmlDocument* self, const gchar* name, GError** error);
	GXmlNode* (*create_text) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_comment) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_cdata) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_pi) (GXmlDocument* self, const gchar* target, const gchar* data);
	gboolean (*save) (GXmlDocument* self, GCancellable* cancellable, GError** error);
	gboolean (*save_as) (GXmlDocument* self, GFile* f, GCancellable* cancellable, GError** error);
	gboolean (*get_indent) (GXmlDocument* self);
	void (*set_indent) (GXmlDocument* self, gboolean value);
	gboolean (*get_ns_top) (GXmlDocument* self);
	void (*set_ns_top) (GXmlDocument* self, gboolean value);
	gboolean (*get_prefix_default_ns) (GXmlDocument* self);
	void (*set_prefix_default_ns) (GXmlDocument* self, gboolean value);
	gboolean (*get_backup) (GXmlDocument* self);
	void (*set_backup) (GXmlDocument* self, gboolean value);
	GXmlNode* (*get_root) (GXmlDocument* self);
	GFile* (*get_file) (GXmlDocument* self);
	void (*set_file) (GXmlDocument* self, GFile* value);
};

struct _GXmlDomImplementationIface {
	GTypeInterface parent_iface;
	GXmlDomDocumentType* (*create_document_type) (GXmlDomImplementation* self, const gchar* qualified_name, const gchar* public_id, const gchar* system_id, GError** error);
	GXmlDomXMLDocument* (*create_document) (GXmlDomImplementation* self, const gchar* nspace, const gchar* qualified_name, GXmlDomDocumentType* doctype, GError** error);
	GXmlDocument* (*create_html_document) (GXmlDomImplementation* self, const gchar* title);
	gboolean (*has_feature) (GXmlDomImplementation* self);
};

struct _GXmlDomDocumentIface {
	GTypeInterface parent_iface;
	GXmlDomHTMLCollection* (*get_elements_by_tag_name) (GXmlDomDocument* self, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name_ns) (GXmlDomDocument* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_class_name) (GXmlDomDocument* self, const gchar* classNames);
	GXmlDomElement* (*create_element) (GXmlDomDocument* self, const gchar* local_name, GError** error);
	GXmlDomElement* (*create_element_ns) (GXmlDomDocument* self, const gchar* namespace, const gchar* qualified_name, GError** error);
	GXmlDomDocumentFragment* (*create_document_fragment) (GXmlDomDocument* self);
	GXmlDomText* (*create_text_node) (GXmlDomDocument* self, const gchar* data, GError** error);
	GXmlDomComment* (*create_comment) (GXmlDomDocument* self, const gchar* data, GError** error);
	GXmlDomProcessingInstruction* (*create_processing_instruction) (GXmlDomDocument* self, const gchar* target, const gchar* data, GError** error);
	GXmlDomNode* (*import_node) (GXmlDomDocument* self, GXmlDomNode* node, gboolean deep, GError** error);
	GXmlDomNode* (*adopt_node) (GXmlDomDocument* self, GXmlDomNode* node, GError** error);
	GXmlDomEvent* (*create_event) (GXmlDomDocument* self, const gchar* interface, GError** error);
	GXmlDomRange* (*create_range) (GXmlDomDocument* self);
	GXmlDomNodeIterator* (*create_node_iterator) (GXmlDomDocument* self, GXmlDomNode* root, gint whatToShow, GXmlDomNodeFilter* filter);
	GXmlDomTreeWalker* (*create_tree_walker) (GXmlDomDocument* self, GXmlDomNode* root, gint what_to_show, GXmlDomNodeFilter* filter);
	GXmlDomImplementation* (*get_implementation) (GXmlDomDocument* self);
	const gchar* (*get_url) (GXmlDomDocument* self);
	const gchar* (*get_document_uri) (GXmlDomDocument* self);
	const gchar* (*get_origin) (GXmlDomDocument* self);
	const gchar* (*get_compat_mode) (GXmlDomDocument* self);
	const gchar* (*get_character_set) (GXmlDomDocument* self);
	const gchar* (*get_content_type) (GXmlDomDocument* self);
	GXmlDomDocumentType* (*get_doctype) (GXmlDomDocument* self);
	GXmlDomElement* (*get_document_element) (GXmlDomDocument* self);
};

struct _GXmlDomNodeIface {
	GTypeInterface parent_iface;
	gboolean (*has_child_nodes) (GXmlDomNode* self);
	void (*normalize) (GXmlDomNode* self);
	gboolean (*is_equal_node) (GXmlDomNode* self, GXmlDomNode* node);
	GXmlDomNodeDocumentPosition (*compare_document_position) (GXmlDomNode* self, GXmlDomNode* other);
	gboolean (*contains) (GXmlDomNode* self, GXmlDomNode* other);
	gchar* (*lookup_prefix) (GXmlDomNode* self, const gchar* nspace);
	gchar* (*lookup_namespace_uri) (GXmlDomNode* self, const gchar* prefix);
	gboolean (*is_default_namespace) (GXmlDomNode* self, const gchar* nspace);
	GXmlDomNode* (*insert_before) (GXmlDomNode* self, GXmlDomNode* node, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*append_child) (GXmlDomNode* self, GXmlDomNode* node, GError** error);
	GXmlDomNode* (*replace_child) (GXmlDomNode* self, GXmlDomNode* node, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*remove_child) (GXmlDomNode* self, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*clone_node) (GXmlDomNode* self, gboolean deep, GError** error);
	GXmlDomNodeNodeType (*get_node_type) (GXmlDomNode* self);
	gchar* (*get_node_name) (GXmlDomNode* self);
	const gchar* (*get_base_uri) (GXmlDomNode* self);
	GXmlDomDocument* (*get_owner_document) (GXmlDomNode* self);
	void (*set_owner_document) (GXmlDomNode* self, GXmlDomDocument* value);
	GXmlDomNode* (*get_parent_node) (GXmlDomNode* self);
	GXmlDomElement* (*get_parent_element) (GXmlDomNode* self);
	GXmlDomNodeList* (*get_child_nodes) (GXmlDomNode* self);
	GXmlDomNode* (*get_first_child) (GXmlDomNode* self);
	GXmlDomNode* (*get_last_child) (GXmlDomNode* self);
	GXmlDomNode* (*get_previous_sibling) (GXmlDomNode* self);
	GXmlDomNode* (*get_next_sibling) (GXmlDomNode* self);
	gchar* (*get_node_value) (GXmlDomNode* self);
	void (*set_node_value) (GXmlDomNode* self, const gchar* value);
	gchar* (*get_text_content) (GXmlDomNode* self);
	void (*set_text_content) (GXmlDomNode* self, const gchar* value);
};

struct _GXmlGomNode {
	GObject parent_instance;
	GXmlGomNodePrivate * priv;
	gchar* _local_name;
	gchar* _prefix;
	gchar* _base_uri;
	gchar* _node_value;
	GXmlDomNode* _parent;
	GXmlDomNodeNodeType _node_type;
	GXmlGomNodeList* _child_nodes;
	GXmlDomDocument* _document;
};

struct _GXmlGomNodeClass {
	GObjectClass parent_class;
};

struct _GXmlDomAttrIface {
	GTypeInterface parent_iface;
	gchar* (*get_namespace_uri) (GXmlDomAttr* self);
	gchar* (*get_prefix) (GXmlDomAttr* self);
	gchar* (*get_local_name) (GXmlDomAttr* self);
	gchar* (*get_name) (GXmlDomAttr* self);
	gchar* (*get_value) (GXmlDomAttr* self);
	void (*set_value) (GXmlDomAttr* self, const gchar* value);
	gboolean (*get_specified) (GXmlDomAttr* self);
};

typedef enum  {
	GXML_DOM_ERROR_INDEX_SIZE_ERROR = 1,
	GXML_DOM_ERROR_DOMSTRING_SIZE_ERROR,
	GXML_DOM_ERROR_HIERARCHY_REQUEST_ERROR,
	GXML_DOM_ERROR_WRONG_DOCUMENT_ERROR,
	GXML_DOM_ERROR_INVALID_CHARACTER_ERROR,
	GXML_DOM_ERROR_NO_DATA_ALLOWED_ERROR,
	GXML_DOM_ERROR_NO_MODIFICATION_ALLOWED_ERROR,
	GXML_DOM_ERROR_NOT_FOUND_ERROR,
	GXML_DOM_ERROR_NOT_SUPPORTED_ERROR,
	GXML_DOM_ERROR_INUSE_ATTRIBUTE_ERROR,
	GXML_DOM_ERROR_INVALID_STATE_ERROR,
	GXML_DOM_ERROR_SYNTAX_ERROR,
	GXML_DOM_ERROR_INVALID_MODIFICATION_ERROR,
	GXML_DOM_ERROR_NAMESPACE_ERROR,
	GXML_DOM_ERROR_INVALID_ACCESS_ERROR,
	GXML_DOM_ERROR_VALIDATION_ERROR,
	GXML_DOM_ERROR_TYPE_MISMATCH_ERROR,
	GXML_DOM_ERROR_SECURITY_ERROR,
	GXML_DOM_ERROR_NETWORK_ERROR,
	GXML_DOM_ERROR_ABORT_ERROR,
	GXML_DOM_ERROR_URL_MISMATCH_ERROR,
	GXML_DOM_ERROR_QUOTA_EXCEEDED_ERROR,
	GXML_DOM_ERROR_TIME_OUT_ERROR,
	GXML_DOM_ERROR_INVALID_NODE_TYPE_ERROR,
	GXML_DOM_ERROR_DATA_CLONE_ERROR
} GXmlDomError;
#define GXML_DOM_ERROR gxml_dom_error_quark ()
struct _GXmlGomNodeList {
	GeeArrayList parent_instance;
	GXmlGomNodeListPrivate * priv;
};

struct _GXmlGomNodeListClass {
	GeeArrayListClass parent_class;
};


static gpointer gxml_gom_node_parent_class = NULL;
static GXmlDomEventTargetIface* gxml_gom_node_gxml_dom_event_target_parent_iface = NULL;
static GXmlDomNodeIface* gxml_gom_node_gxml_dom_node_parent_iface = NULL;
static gpointer gxml_gom_node_list_parent_class = NULL;
static GXmlDomNodeListIface* gxml_gom_node_list_gxml_dom_node_list_parent_iface = NULL;

GType gxml_dom_time_stamp_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_phase_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_listener_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_target_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_document_position_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_node_type_get_type (void) G_GNUC_CONST;
GType gxml_dom_child_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_non_document_type_child_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_html_collection_get_type (void) G_GNUC_CONST;
GType gxml_dom_token_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_named_node_map_get_type (void) G_GNUC_CONST;
GType gxml_dom_element_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_element_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_parent_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_non_element_parent_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_fragment_get_type (void) G_GNUC_CONST;
GType gxml_dom_character_data_get_type (void) G_GNUC_CONST;
GType gxml_dom_text_get_type (void) G_GNUC_CONST;
GType gxml_dom_comment_get_type (void) G_GNUC_CONST;
GType gxml_dom_processing_instruction_get_type (void) G_GNUC_CONST;
GType gxml_dom_range_boundary_points_get_type (void) G_GNUC_CONST;
GType gxml_dom_range_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_filter_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_iterator_get_type (void) G_GNUC_CONST;
GType gxml_dom_tree_walker_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_type_get_type (void) G_GNUC_CONST;
GType gxml_dom_xml_document_get_type (void) G_GNUC_CONST;
GType gxml_element_list_get_type (void) G_GNUC_CONST;
GType gxml_namespace_get_type (void) G_GNUC_CONST;
GType gxml_node_type_get_type (void) G_GNUC_CONST;
GType gxml_node_get_type (void) G_GNUC_CONST;
GType gxml_document_get_type (void) G_GNUC_CONST;
GType gxml_dom_implementation_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_get_type (void) G_GNUC_CONST;
GType gxml_gom_node_get_type (void) G_GNUC_CONST;
GType gxml_gom_node_list_get_type (void) G_GNUC_CONST;
enum  {
	GXML_GOM_NODE_DUMMY_PROPERTY,
	GXML_GOM_NODE_NODE_TYPE,
	GXML_GOM_NODE_NODE_NAME,
	GXML_GOM_NODE_BASE_URI,
	GXML_GOM_NODE_OWNER_DOCUMENT,
	GXML_GOM_NODE_PARENT_NODE,
	GXML_GOM_NODE_PARENT_ELEMENT,
	GXML_GOM_NODE_CHILD_NODES,
	GXML_GOM_NODE_FIRST_CHILD,
	GXML_GOM_NODE_LAST_CHILD,
	GXML_GOM_NODE_PREVIOUS_SIBLING,
	GXML_GOM_NODE_NEXT_SIBLING,
	GXML_GOM_NODE_NODE_VALUE,
	GXML_GOM_NODE_TEXT_CONTENT
};
static gboolean gxml_gom_node_real_has_child_nodes (GXmlDomNode* base);
static void gxml_gom_node_real_normalize (GXmlDomNode* base);
GXmlDomNodeList* gxml_dom_node_get_child_nodes (GXmlDomNode* self);
static gboolean gxml_gom_node_real_is_equal_node (GXmlDomNode* base, GXmlDomNode* node);
gchar* gxml_dom_character_data_get_data (GXmlDomCharacterData* self);
static GXmlDomNodeDocumentPosition gxml_gom_node_real_compare_document_position (GXmlDomNode* base, GXmlDomNode* other);
GXmlDomDocument* gxml_dom_node_get_owner_document (GXmlDomNode* self);
GXmlDomNode* gxml_dom_node_get_parent_node (GXmlDomNode* self);
gboolean gxml_dom_node_contains (GXmlDomNode* self, GXmlDomNode* other);
static gboolean gxml_gom_node_real_contains (GXmlDomNode* base, GXmlDomNode* other);
static gchar* gxml_gom_node_real_lookup_prefix (GXmlDomNode* base, const gchar* nspace);
GType gxml_gom_element_get_type (void) G_GNUC_CONST;
gchar* gxml_gom_element_lookup_prefix (GXmlGomElement* self, const gchar* nspace);
GType gxml_dom_attr_get_type (void) G_GNUC_CONST;
gchar* gxml_dom_node_lookup_prefix (GXmlDomNode* self, const gchar* nspace);
static gchar* gxml_gom_node_real_lookup_namespace_uri (GXmlDomNode* base, const gchar* prefix);
gchar* gxml_gom_element_lookup_namespace_uri (GXmlGomElement* self, const gchar* prefix);
gchar* gxml_dom_node_lookup_namespace_uri (GXmlDomNode* self, const gchar* prefix);
static gboolean gxml_gom_node_real_is_default_namespace (GXmlDomNode* base, const gchar* nspace);
void gxml_gom_node_set_parent (GXmlGomNode* self, GXmlDomNode* node, GError** error);
gchar* gxml_dom_element_get_namespace_uri (GXmlDomElement* self);
gchar* gxml_dom_element_get_prefix (GXmlDomElement* self);
GQuark gxml_dom_error_quark (void);
static GXmlDomNode* gxml_gom_node_real_insert_before (GXmlDomNode* base, GXmlDomNode* node, GXmlDomNode* child, GError** error);
static GXmlDomNode* gxml_gom_node_real_append_child (GXmlDomNode* base, GXmlDomNode* node, GError** error);
GXmlDomNode* gxml_dom_node_insert_before (GXmlDomNode* self, GXmlDomNode* node, GXmlDomNode* child, GError** error);
static GXmlDomNode* gxml_gom_node_real_replace_child (GXmlDomNode* base, GXmlDomNode* node, GXmlDomNode* child, GError** error);
GType gxml_gnode_get_type (void) G_GNUC_CONST;
static GXmlDomNode* gxml_gom_node_real_remove_child (GXmlDomNode* base, GXmlDomNode* child, GError** error);
static void gxml_gom_node_real_add_event_listener (GXmlDomEventTarget* base, const gchar* type, GXmlDomEventListener* callback, gboolean capture);
static void gxml_gom_node_real_remove_event_listener (GXmlDomEventTarget* base, const gchar* type, GXmlDomEventListener* callback, gboolean capture);
static gboolean gxml_gom_node_real_dispatch_event (GXmlDomEventTarget* base, GXmlDomEvent* event, GError** error);
GXmlGomNode* gxml_gom_node_new (void);
GXmlGomNode* gxml_gom_node_construct (GType object_type);
GXmlGomDocument* gxml_gom_document_new (void);
GXmlGomDocument* gxml_gom_document_construct (GType object_type);
GType gxml_gom_document_get_type (void) G_GNUC_CONST;
GXmlDomNode* gxml_dom_node_append_child (GXmlDomNode* self, GXmlDomNode* node, GError** error);
gint gxml_dom_node_list_get_length (GXmlDomNodeList* self);
gchar* gxml_dom_node_get_node_value (GXmlDomNode* self);
GXmlDomText* gxml_dom_document_create_text_node (GXmlDomDocument* self, const gchar* data, GError** error);
static GObject * gxml_gom_node_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
GXmlGomNodeList* gxml_gom_node_list_new (void);
GXmlGomNodeList* gxml_gom_node_list_construct (GType object_type);
static void gxml_gom_node_finalize (GObject* obj);
GXmlDomNodeNodeType gxml_dom_node_get_node_type (GXmlDomNode* self);
gchar* gxml_dom_node_get_node_name (GXmlDomNode* self);
const gchar* gxml_dom_node_get_base_uri (GXmlDomNode* self);
GXmlDomElement* gxml_dom_node_get_parent_element (GXmlDomNode* self);
GXmlDomNode* gxml_dom_node_get_first_child (GXmlDomNode* self);
GXmlDomNode* gxml_dom_node_get_last_child (GXmlDomNode* self);
GXmlDomNode* gxml_dom_node_get_previous_sibling (GXmlDomNode* self);
GXmlDomNode* gxml_dom_node_get_next_sibling (GXmlDomNode* self);
gchar* gxml_dom_node_get_text_content (GXmlDomNode* self);
static void _vala_gxml_gom_node_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
void gxml_dom_node_set_owner_document (GXmlDomNode* self, GXmlDomDocument* value);
void gxml_dom_node_set_node_value (GXmlDomNode* self, const gchar* value);
void gxml_dom_node_set_text_content (GXmlDomNode* self, const gchar* value);
static void _vala_gxml_gom_node_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
enum  {
	GXML_GOM_NODE_LIST_DUMMY_PROPERTY,
	GXML_GOM_NODE_LIST_LENGTH
};
static GXmlDomNode* gxml_gom_node_list_real_item (GXmlDomNodeList* base, gint index);
static void _vala_gxml_gom_node_list_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);


static gboolean gxml_gom_node_real_has_child_nodes (GXmlDomNode* base) {
	GXmlGomNode * self;
	gboolean result = FALSE;
	GXmlGomNodeList* _tmp0_ = NULL;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
	self = (GXmlGomNode*) base;
	_tmp0_ = self->_child_nodes;
	_tmp1_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp0_);
	_tmp2_ = _tmp1_;
	result = _tmp2_ > 0;
	return result;
}


static void gxml_gom_node_real_normalize (GXmlDomNode* base) {
	GXmlGomNode * self;
	self = (GXmlGomNode*) base;
	{
		gint i = 0;
		i = 0;
		{
			gboolean _tmp0_ = FALSE;
			_tmp0_ = TRUE;
			while (TRUE) {
				gint _tmp2_ = 0;
				GXmlDomNodeList* _tmp3_ = NULL;
				GXmlDomNodeList* _tmp4_ = NULL;
				GXmlDomNodeList* _tmp5_ = NULL;
				gint _tmp6_ = 0;
				gint _tmp7_ = 0;
				gboolean _tmp8_ = FALSE;
				GXmlDomNode* n = NULL;
				GXmlDomNodeList* _tmp9_ = NULL;
				GXmlDomNodeList* _tmp10_ = NULL;
				GXmlDomNodeList* _tmp11_ = NULL;
				gint _tmp12_ = 0;
				gpointer _tmp13_ = NULL;
				GXmlDomNode* _tmp14_ = NULL;
				GXmlDomNode* _tmp15_ = NULL;
				if (!_tmp0_) {
					gint _tmp1_ = 0;
					_tmp1_ = i;
					i = _tmp1_ + 1;
				}
				_tmp0_ = FALSE;
				_tmp2_ = i;
				_tmp3_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
				_tmp4_ = _tmp3_;
				_tmp5_ = _tmp4_;
				_tmp6_ = gee_collection_get_size ((GeeCollection*) _tmp5_);
				_tmp7_ = _tmp6_;
				_tmp8_ = !(_tmp2_ < _tmp7_);
				_g_object_unref0 (_tmp5_);
				if (_tmp8_) {
					break;
				}
				_tmp9_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
				_tmp10_ = _tmp9_;
				_tmp11_ = _tmp10_;
				_tmp12_ = i;
				_tmp13_ = gee_list_get ((GeeList*) _tmp11_, _tmp12_);
				_tmp14_ = (GXmlDomNode*) _tmp13_;
				_g_object_unref0 (_tmp11_);
				n = _tmp14_;
				_tmp15_ = n;
				if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp15_, GXML_TYPE_DOM_TEXT)) {
					GXmlDomNodeList* _tmp16_ = NULL;
					GXmlDomNodeList* _tmp17_ = NULL;
					GXmlDomNodeList* _tmp18_ = NULL;
					gint _tmp19_ = 0;
					gpointer _tmp20_ = NULL;
					GXmlDomNode* _tmp21_ = NULL;
					_tmp16_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
					_tmp17_ = _tmp16_;
					_tmp18_ = _tmp17_;
					_tmp19_ = i;
					_tmp20_ = gee_list_remove_at ((GeeList*) _tmp18_, _tmp19_);
					_tmp21_ = (GXmlDomNode*) _tmp20_;
					_g_object_unref0 (_tmp21_);
					_g_object_unref0 (_tmp18_);
				}
				_g_object_unref0 (n);
			}
		}
	}
}


static gboolean gxml_gom_node_real_is_equal_node (GXmlDomNode* base, GXmlDomNode* node) {
	GXmlGomNode * self;
	gboolean result = FALSE;
	GXmlDomNode* _tmp0_ = NULL;
	self = (GXmlGomNode*) base;
	_tmp0_ = node;
	if (_tmp0_ == NULL) {
		result = FALSE;
		return result;
	}
	if (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_CHARACTER_DATA)) {
		gchar* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
		GXmlDomNode* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		gboolean _tmp8_ = FALSE;
		_tmp1_ = gxml_dom_character_data_get_data ((GXmlDomCharacterData*) (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_COMMENT) ? ((GXmlDomComment*) self) : NULL));
		_tmp2_ = _tmp1_;
		_tmp3_ = _tmp2_;
		_tmp4_ = node;
		_tmp5_ = gxml_dom_character_data_get_data ((GXmlDomCharacterData*) (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, GXML_TYPE_DOM_COMMENT) ? ((GXmlDomComment*) _tmp4_) : NULL));
		_tmp6_ = _tmp5_;
		_tmp7_ = _tmp6_;
		_tmp8_ = g_strcmp0 (_tmp3_, _tmp7_) == 0;
		_g_free0 (_tmp7_);
		_g_free0 (_tmp3_);
		result = _tmp8_;
		return result;
	}
	result = FALSE;
	return result;
}


static GXmlDomNodeDocumentPosition gxml_gom_node_real_compare_document_position (GXmlDomNode* base, GXmlDomNode* other) {
	GXmlGomNode * self;
	GXmlDomNodeDocumentPosition result = 0;
	GXmlDomNode* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	GXmlDomDocument* _tmp2_ = NULL;
	GXmlDomDocument* _tmp3_ = NULL;
	GXmlDomNode* _tmp4_ = NULL;
	GXmlDomDocument* _tmp5_ = NULL;
	GXmlDomDocument* _tmp6_ = NULL;
	GXmlDomNode* _tmp13_ = NULL;
	gboolean _tmp14_ = FALSE;
	GXmlDomNode* _tmp15_ = NULL;
	GXmlDomNode* _tmp16_ = NULL;
	GXmlDomNode* _tmp17_ = NULL;
	GXmlDomNode* _tmp18_ = NULL;
	gboolean _tmp19_ = FALSE;
	gboolean _tmp20_ = FALSE;
	GXmlDomNode* _tmp35_ = NULL;
	gboolean _tmp36_ = FALSE;
	const gchar* _tmp37_ = NULL;
	self = (GXmlGomNode*) base;
	g_return_val_if_fail (other != NULL, 0);
	_tmp0_ = other;
	if ((G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_NODE) ? ((GXmlDomNode*) self) : NULL) == _tmp0_) {
		result = GXML_DOM_NODE_DOCUMENT_POSITION_NONE;
		return result;
	}
	_tmp2_ = gxml_dom_node_get_owner_document ((GXmlDomNode*) self);
	_tmp3_ = _tmp2_;
	_tmp4_ = other;
	_tmp5_ = gxml_dom_node_get_owner_document (_tmp4_);
	_tmp6_ = _tmp5_;
	if (_tmp3_ != _tmp6_) {
		_tmp1_ = TRUE;
	} else {
		GXmlDomNode* _tmp7_ = NULL;
		GXmlDomNode* _tmp8_ = NULL;
		GXmlDomNode* _tmp9_ = NULL;
		GXmlDomNode* _tmp10_ = NULL;
		_tmp7_ = other;
		_tmp8_ = gxml_dom_node_get_parent_node (_tmp7_);
		_tmp9_ = _tmp8_;
		_tmp10_ = _tmp9_;
		_tmp1_ = _tmp10_ == NULL;
		_g_object_unref0 (_tmp10_);
	}
	if (_tmp1_) {
		GXmlDomNodeDocumentPosition p = 0;
		p = GXML_DOM_NODE_DOCUMENT_POSITION_DISCONNECTED & GXML_DOM_NODE_DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC;
		if ((&self) > (&other)) {
			GXmlDomNodeDocumentPosition _tmp11_ = 0;
			_tmp11_ = p;
			p = _tmp11_ & GXML_DOM_NODE_DOCUMENT_POSITION_PRECEDING;
		} else {
			GXmlDomNodeDocumentPosition _tmp12_ = 0;
			_tmp12_ = p;
			p = _tmp12_ & GXML_DOM_NODE_DOCUMENT_POSITION_FOLLOWING;
		}
		result = p;
		return result;
	}
	_tmp13_ = other;
	_tmp14_ = gxml_dom_node_contains (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_NODE) ? ((GXmlDomNode*) self) : NULL, _tmp13_);
	if (_tmp14_) {
		result = GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINED_BY & GXML_DOM_NODE_DOCUMENT_POSITION_FOLLOWING;
		return result;
	}
	_tmp15_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) self);
	_tmp16_ = _tmp15_;
	_tmp17_ = _tmp16_;
	_tmp18_ = other;
	_tmp19_ = gxml_dom_node_contains (_tmp17_, _tmp18_);
	_tmp20_ = _tmp19_;
	_g_object_unref0 (_tmp17_);
	if (_tmp20_) {
		GXmlDomNode* par = NULL;
		GXmlDomNode* _tmp21_ = NULL;
		GXmlDomNode* _tmp22_ = NULL;
		GXmlDomNode* _tmp23_ = NULL;
		GXmlDomNodeList* _tmp24_ = NULL;
		GXmlDomNodeList* _tmp25_ = NULL;
		GXmlDomNodeList* _tmp26_ = NULL;
		gint _tmp27_ = 0;
		GXmlDomNode* _tmp28_ = NULL;
		GXmlDomNodeList* _tmp29_ = NULL;
		GXmlDomNodeList* _tmp30_ = NULL;
		GXmlDomNodeList* _tmp31_ = NULL;
		GXmlDomNode* _tmp32_ = NULL;
		gint _tmp33_ = 0;
		gboolean _tmp34_ = FALSE;
		_tmp21_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) self);
		_tmp22_ = _tmp21_;
		par = _tmp22_;
		_tmp23_ = par;
		_tmp24_ = gxml_dom_node_get_child_nodes (_tmp23_);
		_tmp25_ = _tmp24_;
		_tmp26_ = _tmp25_;
		_tmp27_ = gee_list_index_of ((GeeList*) _tmp26_, (GXmlDomNode*) self);
		_tmp28_ = par;
		_tmp29_ = gxml_dom_node_get_child_nodes (_tmp28_);
		_tmp30_ = _tmp29_;
		_tmp31_ = _tmp30_;
		_tmp32_ = other;
		_tmp33_ = gee_list_index_of ((GeeList*) _tmp31_, _tmp32_);
		_tmp34_ = _tmp27_ > _tmp33_;
		_g_object_unref0 (_tmp31_);
		_g_object_unref0 (_tmp26_);
		if (_tmp34_) {
			result = GXML_DOM_NODE_DOCUMENT_POSITION_PRECEDING;
			_g_object_unref0 (par);
			return result;
		} else {
			result = GXML_DOM_NODE_DOCUMENT_POSITION_FOLLOWING;
			_g_object_unref0 (par);
			return result;
		}
		_g_object_unref0 (par);
	}
	_tmp35_ = other;
	_tmp36_ = gxml_dom_node_contains (_tmp35_, (GXmlDomNode*) self);
	if (_tmp36_) {
		result = GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINS & GXML_DOM_NODE_DOCUMENT_POSITION_PRECEDING;
		return result;
	}
	_tmp37_ = _ ("Can't find node position");
	g_warning ("GomNode.vala:203: %s", _tmp37_);
	result = GXML_DOM_NODE_DOCUMENT_POSITION_NONE;
	return result;
}


static gboolean gxml_gom_node_real_contains (GXmlDomNode* base, GXmlDomNode* other) {
	GXmlGomNode * self;
	gboolean result = FALSE;
	GXmlDomNode* _tmp0_ = NULL;
	GXmlDomNodeList* _tmp1_ = NULL;
	GXmlDomNodeList* _tmp2_ = NULL;
	GXmlDomNodeList* _tmp3_ = NULL;
	GXmlDomNode* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
	gboolean _tmp6_ = FALSE;
	self = (GXmlGomNode*) base;
	_tmp0_ = other;
	if (_tmp0_ == NULL) {
		result = FALSE;
		return result;
	}
	_tmp1_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
	_tmp2_ = _tmp1_;
	_tmp3_ = _tmp2_;
	_tmp4_ = other;
	_tmp5_ = gee_collection_contains ((GeeCollection*) _tmp3_, _tmp4_);
	_tmp6_ = _tmp5_;
	_g_object_unref0 (_tmp3_);
	result = _tmp6_;
	return result;
}


static gchar* gxml_gom_node_real_lookup_prefix (GXmlDomNode* base, const gchar* nspace) {
	GXmlGomNode * self;
	gchar* result = NULL;
	gboolean _tmp0_ = FALSE;
	self = (GXmlGomNode*) base;
	if (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_DOCUMENT_TYPE)) {
		_tmp0_ = TRUE;
	} else {
		_tmp0_ = G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_DOCUMENT_FRAGMENT);
	}
	if (_tmp0_) {
		result = NULL;
		return result;
	}
	if (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_ELEMENT)) {
		const gchar* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
		_tmp1_ = nspace;
		_tmp2_ = gxml_gom_element_lookup_prefix (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_GOM_ELEMENT) ? ((GXmlGomElement*) self) : NULL, _tmp1_);
		result = _tmp2_;
		return result;
	}
	if (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_ATTR)) {
		GXmlDomNode* _tmp3_ = NULL;
		GXmlDomNode* _tmp4_ = NULL;
		GXmlDomNode* _tmp5_ = NULL;
		gboolean _tmp6_ = FALSE;
		GXmlDomNode* _tmp7_ = NULL;
		GXmlDomNode* _tmp8_ = NULL;
		GXmlDomNode* _tmp9_ = NULL;
		const gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
		_tmp3_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) self);
		_tmp4_ = _tmp3_;
		_tmp5_ = _tmp4_;
		_tmp6_ = _tmp5_ == NULL;
		_g_object_unref0 (_tmp5_);
		if (_tmp6_) {
			result = NULL;
			return result;
		}
		_tmp7_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) self);
		_tmp8_ = _tmp7_;
		_tmp9_ = _tmp8_;
		_tmp10_ = nspace;
		_tmp11_ = gxml_dom_node_lookup_prefix (_tmp9_, _tmp10_);
		_tmp12_ = _tmp11_;
		_g_object_unref0 (_tmp9_);
		result = _tmp12_;
		return result;
	}
	result = NULL;
	return result;
}


static gchar* gxml_gom_node_real_lookup_namespace_uri (GXmlDomNode* base, const gchar* prefix) {
	GXmlGomNode * self;
	gchar* result = NULL;
	gboolean _tmp0_ = FALSE;
	self = (GXmlGomNode*) base;
	if (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_DOCUMENT_TYPE)) {
		_tmp0_ = TRUE;
	} else {
		_tmp0_ = G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_DOCUMENT_FRAGMENT);
	}
	if (_tmp0_) {
		result = NULL;
		return result;
	}
	if (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_ELEMENT)) {
		const gchar* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
		_tmp1_ = prefix;
		_tmp2_ = gxml_gom_element_lookup_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_GOM_ELEMENT) ? ((GXmlGomElement*) self) : NULL, _tmp1_);
		result = _tmp2_;
		return result;
	}
	if (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_ATTR)) {
		GXmlDomNode* _tmp3_ = NULL;
		GXmlDomNode* _tmp4_ = NULL;
		GXmlDomNode* _tmp5_ = NULL;
		gboolean _tmp6_ = FALSE;
		GXmlDomNode* _tmp7_ = NULL;
		GXmlDomNode* _tmp8_ = NULL;
		GXmlDomNode* _tmp9_ = NULL;
		const gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
		_tmp3_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) self);
		_tmp4_ = _tmp3_;
		_tmp5_ = _tmp4_;
		_tmp6_ = _tmp5_ == NULL;
		_g_object_unref0 (_tmp5_);
		if (_tmp6_) {
			result = NULL;
			return result;
		}
		_tmp7_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) self);
		_tmp8_ = _tmp7_;
		_tmp9_ = _tmp8_;
		_tmp10_ = prefix;
		_tmp11_ = gxml_dom_node_lookup_namespace_uri (_tmp9_, _tmp10_);
		_tmp12_ = _tmp11_;
		_g_object_unref0 (_tmp9_);
		result = _tmp12_;
		return result;
	}
	result = NULL;
	return result;
}


static gboolean gxml_gom_node_real_is_default_namespace (GXmlDomNode* base, const gchar* nspace) {
	GXmlGomNode * self;
	gboolean result = FALSE;
	gchar* ns = NULL;
	gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	self = (GXmlGomNode*) base;
	_tmp0_ = gxml_dom_node_lookup_namespace_uri ((GXmlDomNode*) self, NULL);
	ns = _tmp0_;
	_tmp1_ = ns;
	_tmp2_ = nspace;
	if (g_strcmp0 (_tmp1_, _tmp2_) == 0) {
		result = TRUE;
		_g_free0 (ns);
		return result;
	}
	result = FALSE;
	_g_free0 (ns);
	return result;
}


/**
   * Sets node's parent and checks for namespace conflics.
   */
static gpointer _g_object_ref0 (gpointer self) {
	return self ? g_object_ref (self) : NULL;
}


void gxml_gom_node_set_parent (GXmlGomNode* self, GXmlDomNode* node, GError** error) {
	GXmlDomNode* _tmp57_ = NULL;
	GXmlDomDocument* _tmp58_ = NULL;
	GXmlDomDocument* _tmp59_ = NULL;
	GXmlDomDocument* _tmp60_ = NULL;
	GXmlDomNode* _tmp61_ = NULL;
	GXmlDomNode* _tmp62_ = NULL;
	GError * _inner_error_ = NULL;
	g_return_if_fail (self != NULL);
	g_return_if_fail (node != NULL);
	if (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_ELEMENT)) {
		GXmlDomElement* e = NULL;
		GXmlDomElement* _tmp0_ = NULL;
		gboolean _tmp1_ = FALSE;
		GXmlDomElement* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
		gchar* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		gboolean _tmp6_ = FALSE;
		_tmp0_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) self) : NULL);
		e = _tmp0_;
		_tmp2_ = e;
		_tmp3_ = gxml_dom_element_get_namespace_uri (_tmp2_);
		_tmp4_ = _tmp3_;
		_tmp5_ = _tmp4_;
		_tmp6_ = _tmp5_ != NULL;
		_g_free0 (_tmp5_);
		if (_tmp6_) {
			_tmp1_ = TRUE;
		} else {
			GXmlDomElement* _tmp7_ = NULL;
			gchar* _tmp8_ = NULL;
			gchar* _tmp9_ = NULL;
			gchar* _tmp10_ = NULL;
			_tmp7_ = e;
			_tmp8_ = gxml_dom_element_get_prefix (_tmp7_);
			_tmp9_ = _tmp8_;
			_tmp10_ = _tmp9_;
			_tmp1_ = _tmp10_ != NULL;
			_g_free0 (_tmp10_);
		}
		if (_tmp1_) {
			gchar* nsprefix = NULL;
			GXmlDomNode* _tmp11_ = NULL;
			GXmlDomElement* _tmp12_ = NULL;
			gchar* _tmp13_ = NULL;
			gchar* _tmp14_ = NULL;
			gchar* _tmp15_ = NULL;
			gchar* _tmp16_ = NULL;
			gchar* _tmp17_ = NULL;
			gchar* nsuri = NULL;
			GXmlDomNode* _tmp18_ = NULL;
			GXmlDomElement* _tmp19_ = NULL;
			gchar* _tmp20_ = NULL;
			gchar* _tmp21_ = NULL;
			gchar* _tmp22_ = NULL;
			gchar* _tmp23_ = NULL;
			gchar* _tmp24_ = NULL;
			gboolean _tmp25_ = FALSE;
			const gchar* _tmp26_ = NULL;
			gboolean _tmp41_ = FALSE;
			const gchar* _tmp42_ = NULL;
			_tmp11_ = node;
			_tmp12_ = e;
			_tmp13_ = gxml_dom_element_get_namespace_uri (_tmp12_);
			_tmp14_ = _tmp13_;
			_tmp15_ = _tmp14_;
			_tmp16_ = gxml_dom_node_lookup_prefix (_tmp11_, _tmp15_);
			_tmp17_ = _tmp16_;
			_g_free0 (_tmp15_);
			nsprefix = _tmp17_;
			_tmp18_ = node;
			_tmp19_ = e;
			_tmp20_ = gxml_dom_element_get_prefix (_tmp19_);
			_tmp21_ = _tmp20_;
			_tmp22_ = _tmp21_;
			_tmp23_ = gxml_dom_node_lookup_namespace_uri (_tmp18_, _tmp22_);
			_tmp24_ = _tmp23_;
			_g_free0 (_tmp22_);
			nsuri = _tmp24_;
			_tmp26_ = nsprefix;
			if (_tmp26_ != NULL) {
				const gchar* _tmp27_ = NULL;
				GXmlDomElement* _tmp28_ = NULL;
				gchar* _tmp29_ = NULL;
				gchar* _tmp30_ = NULL;
				gchar* _tmp31_ = NULL;
				_tmp27_ = nsprefix;
				_tmp28_ = e;
				_tmp29_ = gxml_dom_element_get_prefix (_tmp28_);
				_tmp30_ = _tmp29_;
				_tmp31_ = _tmp30_;
				_tmp25_ = g_strcmp0 (_tmp27_, _tmp31_) != 0;
				_g_free0 (_tmp31_);
			} else {
				_tmp25_ = FALSE;
			}
			if (_tmp25_) {
				const gchar* _tmp32_ = NULL;
				GXmlDomElement* _tmp33_ = NULL;
				gchar* _tmp34_ = NULL;
				gchar* _tmp35_ = NULL;
				gchar* _tmp36_ = NULL;
				gchar* _tmp37_ = NULL;
				gchar* _tmp38_ = NULL;
				GError* _tmp39_ = NULL;
				GError* _tmp40_ = NULL;
				_tmp32_ = _ ("Trying to add a namespaced element to a parent with invalid prefix for" \
" namespace %s");
				_tmp33_ = e;
				_tmp34_ = gxml_dom_element_get_namespace_uri (_tmp33_);
				_tmp35_ = _tmp34_;
				_tmp36_ = _tmp35_;
				_tmp37_ = g_strdup_printf (_tmp32_, _tmp36_);
				_tmp38_ = _tmp37_;
				_tmp39_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NAMESPACE_ERROR, _tmp38_);
				_tmp40_ = _tmp39_;
				_g_free0 (_tmp38_);
				_g_free0 (_tmp36_);
				_inner_error_ = _tmp40_;
				g_propagate_error (error, _inner_error_);
				_g_free0 (nsuri);
				_g_free0 (nsprefix);
				_g_object_unref0 (e);
				return;
			}
			_tmp42_ = nsuri;
			if (_tmp42_ != NULL) {
				const gchar* _tmp43_ = NULL;
				GXmlDomElement* _tmp44_ = NULL;
				gchar* _tmp45_ = NULL;
				gchar* _tmp46_ = NULL;
				gchar* _tmp47_ = NULL;
				_tmp43_ = nsuri;
				_tmp44_ = e;
				_tmp45_ = gxml_dom_element_get_namespace_uri (_tmp44_);
				_tmp46_ = _tmp45_;
				_tmp47_ = _tmp46_;
				_tmp41_ = g_strcmp0 (_tmp43_, _tmp47_) != 0;
				_g_free0 (_tmp47_);
			} else {
				_tmp41_ = FALSE;
			}
			if (_tmp41_) {
				const gchar* _tmp48_ = NULL;
				GXmlDomElement* _tmp49_ = NULL;
				gchar* _tmp50_ = NULL;
				gchar* _tmp51_ = NULL;
				gchar* _tmp52_ = NULL;
				gchar* _tmp53_ = NULL;
				gchar* _tmp54_ = NULL;
				GError* _tmp55_ = NULL;
				GError* _tmp56_ = NULL;
				_tmp48_ = _ ("Trying to add a namespaced element to a parent with invalid URI for pr" \
"efix %s");
				_tmp49_ = e;
				_tmp50_ = gxml_dom_element_get_prefix (_tmp49_);
				_tmp51_ = _tmp50_;
				_tmp52_ = _tmp51_;
				_tmp53_ = g_strdup_printf (_tmp48_, _tmp52_);
				_tmp54_ = _tmp53_;
				_tmp55_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NAMESPACE_ERROR, _tmp54_);
				_tmp56_ = _tmp55_;
				_g_free0 (_tmp54_);
				_g_free0 (_tmp52_);
				_inner_error_ = _tmp56_;
				g_propagate_error (error, _inner_error_);
				_g_free0 (nsuri);
				_g_free0 (nsprefix);
				_g_object_unref0 (e);
				return;
			}
			_g_free0 (nsuri);
			_g_free0 (nsprefix);
		}
		_g_object_unref0 (e);
	}
	_tmp57_ = node;
	_tmp58_ = gxml_dom_node_get_owner_document (_tmp57_);
	_tmp59_ = _tmp58_;
	_tmp60_ = _g_object_ref0 (_tmp59_);
	_g_object_unref0 (self->_document);
	self->_document = _tmp60_;
	_tmp61_ = node;
	_tmp62_ = _g_object_ref0 (_tmp61_);
	_g_object_unref0 (self->_parent);
	self->_parent = _tmp62_;
}


static GXmlDomNode* gxml_gom_node_real_insert_before (GXmlDomNode* base, GXmlDomNode* node, GXmlDomNode* child, GError** error) {
	GXmlGomNode * self;
	GXmlDomNode* result = NULL;
	GXmlDomNode* _tmp0_ = NULL;
	gboolean _tmp3_ = FALSE;
	GXmlDomNode* _tmp4_ = NULL;
	gboolean _tmp9_ = FALSE;
	gboolean _tmp10_ = FALSE;
	gboolean _tmp13_ = FALSE;
	gboolean _tmp14_ = FALSE;
	gboolean _tmp15_ = FALSE;
	gboolean _tmp16_ = FALSE;
	gboolean _tmp17_ = FALSE;
	GXmlDomNode* _tmp18_ = NULL;
	gboolean _tmp26_ = FALSE;
	gboolean _tmp27_ = FALSE;
	GXmlDomNode* _tmp28_ = NULL;
	GXmlDomNode* _tmp33_ = NULL;
	GXmlDomNodeList* _tmp47_ = NULL;
	GXmlDomNodeList* _tmp48_ = NULL;
	GXmlDomNodeList* _tmp49_ = NULL;
	GXmlDomNode* _tmp50_ = NULL;
	GXmlDomNode* _tmp51_ = NULL;
	GXmlDomNode* _tmp52_ = NULL;
	GError * _inner_error_ = NULL;
	self = (GXmlGomNode*) base;
	g_return_val_if_fail (node != NULL, NULL);
	_tmp0_ = node;
	if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GXML_TYPE_GOM_NODE)) {
		const gchar* _tmp1_ = NULL;
		GError* _tmp2_ = NULL;
		_tmp1_ = _ ("Invalid attempt to add invalid node type");
		_tmp2_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_INVALID_NODE_TYPE_ERROR, _tmp1_);
		_inner_error_ = _tmp2_;
		g_propagate_error (error, _inner_error_);
		return NULL;
	}
	_tmp4_ = child;
	if (_tmp4_ != NULL) {
		GXmlDomNode* _tmp5_ = NULL;
		gboolean _tmp6_ = FALSE;
		_tmp5_ = child;
		_tmp6_ = gxml_dom_node_contains ((GXmlDomNode*) self, _tmp5_);
		_tmp3_ = !_tmp6_;
	} else {
		_tmp3_ = FALSE;
	}
	if (_tmp3_) {
		const gchar* _tmp7_ = NULL;
		GError* _tmp8_ = NULL;
		_tmp7_ = _ ("Can't find child to insert node before");
		_tmp8_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NOT_FOUND_ERROR, _tmp7_);
		_inner_error_ = _tmp8_;
		g_propagate_error (error, _inner_error_);
		return NULL;
	}
	if (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_DOCUMENT)) {
		_tmp10_ = TRUE;
	} else {
		_tmp10_ = G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_ELEMENT);
	}
	if (_tmp10_) {
		_tmp9_ = TRUE;
	} else {
		_tmp9_ = G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_DOCUMENT_FRAGMENT);
	}
	if (!_tmp9_) {
		const gchar* _tmp11_ = NULL;
		GError* _tmp12_ = NULL;
		_tmp11_ = _ ("Invalid attempt to insert a node");
		_tmp12_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_HIERARCHY_REQUEST_ERROR, _tmp11_);
		_inner_error_ = _tmp12_;
		g_propagate_error (error, _inner_error_);
		return NULL;
	}
	_tmp18_ = node;
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp18_, GXML_TYPE_DOM_DOCUMENT_FRAGMENT)) {
		_tmp17_ = TRUE;
	} else {
		GXmlDomNode* _tmp19_ = NULL;
		_tmp19_ = node;
		_tmp17_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp19_, GXML_TYPE_DOM_DOCUMENT_TYPE);
	}
	if (_tmp17_) {
		_tmp16_ = TRUE;
	} else {
		GXmlDomNode* _tmp20_ = NULL;
		_tmp20_ = node;
		_tmp16_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp20_, GXML_TYPE_DOM_ELEMENT);
	}
	if (_tmp16_) {
		_tmp15_ = TRUE;
	} else {
		GXmlDomNode* _tmp21_ = NULL;
		_tmp21_ = node;
		_tmp15_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp21_, GXML_TYPE_DOM_TEXT);
	}
	if (_tmp15_) {
		_tmp14_ = TRUE;
	} else {
		GXmlDomNode* _tmp22_ = NULL;
		_tmp22_ = node;
		_tmp14_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp22_, GXML_TYPE_DOM_PROCESSING_INSTRUCTION);
	}
	if (_tmp14_) {
		_tmp13_ = TRUE;
	} else {
		GXmlDomNode* _tmp23_ = NULL;
		_tmp23_ = node;
		_tmp13_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp23_, GXML_TYPE_DOM_COMMENT);
	}
	if (!_tmp13_) {
		const gchar* _tmp24_ = NULL;
		GError* _tmp25_ = NULL;
		_tmp24_ = _ ("Invalid attempt to insert an invalid node type");
		_tmp25_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_HIERARCHY_REQUEST_ERROR, _tmp24_);
		_inner_error_ = _tmp25_;
		g_propagate_error (error, _inner_error_);
		return NULL;
	}
	_tmp28_ = node;
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp28_, GXML_TYPE_DOM_TEXT)) {
		_tmp27_ = G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_DOCUMENT);
	} else {
		_tmp27_ = FALSE;
	}
	if (_tmp27_) {
		_tmp26_ = TRUE;
	} else {
		gboolean _tmp29_ = FALSE;
		GXmlDomNode* _tmp30_ = NULL;
		_tmp30_ = node;
		if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp30_, GXML_TYPE_DOM_DOCUMENT_TYPE)) {
			_tmp29_ = !G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_DOCUMENT);
		} else {
			_tmp29_ = FALSE;
		}
		_tmp26_ = _tmp29_;
	}
	if (_tmp26_) {
		const gchar* _tmp31_ = NULL;
		GError* _tmp32_ = NULL;
		_tmp31_ = _ ("Invalid attempt to insert a document or text type to an invalid parent" \
" node");
		_tmp32_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_HIERARCHY_REQUEST_ERROR, _tmp31_);
		_inner_error_ = _tmp32_;
		g_propagate_error (error, _inner_error_);
		return NULL;
	}
	_tmp33_ = child;
	if (_tmp33_ != NULL) {
		gint i = 0;
		GXmlDomNodeList* _tmp34_ = NULL;
		GXmlDomNodeList* _tmp35_ = NULL;
		GXmlDomNodeList* _tmp36_ = NULL;
		GXmlDomNode* _tmp37_ = NULL;
		gint _tmp38_ = 0;
		gint _tmp39_ = 0;
		GXmlDomNodeList* _tmp40_ = NULL;
		GXmlDomNodeList* _tmp41_ = NULL;
		GXmlDomNodeList* _tmp42_ = NULL;
		gint _tmp43_ = 0;
		GXmlDomNode* _tmp44_ = NULL;
		GXmlDomNode* _tmp45_ = NULL;
		GXmlDomNode* _tmp46_ = NULL;
		_tmp34_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
		_tmp35_ = _tmp34_;
		_tmp36_ = _tmp35_;
		_tmp37_ = child;
		_tmp38_ = gee_list_index_of ((GeeList*) _tmp36_, G_TYPE_CHECK_INSTANCE_TYPE (_tmp37_, GXML_TYPE_DOM_NODE) ? ((GXmlDomNode*) _tmp37_) : NULL);
		_tmp39_ = _tmp38_;
		_g_object_unref0 (_tmp36_);
		i = _tmp39_;
		_tmp40_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
		_tmp41_ = _tmp40_;
		_tmp42_ = _tmp41_;
		_tmp43_ = i;
		_tmp44_ = node;
		gee_list_insert ((GeeList*) _tmp42_, _tmp43_, G_TYPE_CHECK_INSTANCE_TYPE (_tmp44_, GXML_TYPE_DOM_NODE) ? ((GXmlDomNode*) _tmp44_) : NULL);
		_g_object_unref0 (_tmp42_);
		_tmp45_ = node;
		_tmp46_ = _g_object_ref0 (_tmp45_);
		result = _tmp46_;
		return result;
	}
	_tmp47_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
	_tmp48_ = _tmp47_;
	_tmp49_ = _tmp48_;
	_tmp50_ = node;
	gee_collection_add ((GeeCollection*) _tmp49_, G_TYPE_CHECK_INSTANCE_TYPE (_tmp50_, GXML_TYPE_DOM_NODE) ? ((GXmlDomNode*) _tmp50_) : NULL);
	_g_object_unref0 (_tmp49_);
	_tmp51_ = node;
	_tmp52_ = _g_object_ref0 (_tmp51_);
	result = _tmp52_;
	return result;
}


static GXmlDomNode* gxml_gom_node_real_append_child (GXmlDomNode* base, GXmlDomNode* node, GError** error) {
	GXmlGomNode * self;
	GXmlDomNode* result = NULL;
	GXmlDomNode* _tmp0_ = NULL;
	GXmlDomDocument* _tmp3_ = NULL;
	GXmlDomDocument* _tmp4_ = NULL;
	GXmlDomNode* _tmp5_ = NULL;
	GXmlDomDocument* _tmp6_ = NULL;
	GXmlDomDocument* _tmp7_ = NULL;
	GXmlDomNode* _tmp10_ = NULL;
	GXmlDomNode* _tmp11_ = NULL;
	GXmlDomNode* _tmp12_ = NULL;
	GXmlDomNode* _tmp13_ = NULL;
	GXmlDomNode* _tmp14_ = NULL;
	GError * _inner_error_ = NULL;
	self = (GXmlGomNode*) base;
	g_return_val_if_fail (node != NULL, NULL);
	_tmp0_ = node;
	if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GXML_TYPE_GOM_NODE)) {
		const gchar* _tmp1_ = NULL;
		GError* _tmp2_ = NULL;
		_tmp1_ = _ ("Node type is invalid. Can't append as child");
		_tmp2_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_HIERARCHY_REQUEST_ERROR, _tmp1_);
		_inner_error_ = _tmp2_;
		g_propagate_error (error, _inner_error_);
		return NULL;
	}
	_tmp3_ = gxml_dom_node_get_owner_document ((GXmlDomNode*) self);
	_tmp4_ = _tmp3_;
	_tmp5_ = node;
	_tmp6_ = gxml_dom_node_get_owner_document (_tmp5_);
	_tmp7_ = _tmp6_;
	if (_tmp4_ != _tmp7_) {
		const gchar* _tmp8_ = NULL;
		GError* _tmp9_ = NULL;
		_tmp8_ = _ ("Invalid attempt to append a child with different parent document");
		_tmp9_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_HIERARCHY_REQUEST_ERROR, _tmp8_);
		_inner_error_ = _tmp9_;
		g_propagate_error (error, _inner_error_);
		return NULL;
	}
	_tmp10_ = node;
	gxml_gom_node_set_parent (G_TYPE_CHECK_INSTANCE_TYPE (_tmp10_, GXML_TYPE_GOM_NODE) ? ((GXmlGomNode*) _tmp10_) : NULL, (GXmlDomNode*) self, &_inner_error_);
	if (G_UNLIKELY (_inner_error_ != NULL)) {
		g_propagate_error (error, _inner_error_);
		return NULL;
	}
	_tmp12_ = node;
	_tmp13_ = gxml_dom_node_insert_before ((GXmlDomNode*) self, _tmp12_, NULL, &_inner_error_);
	_tmp11_ = _tmp13_;
	if (G_UNLIKELY (_inner_error_ != NULL)) {
		g_propagate_error (error, _inner_error_);
		return NULL;
	}
	_tmp14_ = _tmp11_;
	_tmp11_ = NULL;
	result = _tmp14_;
	_g_object_unref0 (_tmp11_);
	return result;
}


static GXmlDomNode* gxml_gom_node_real_replace_child (GXmlDomNode* base, GXmlDomNode* node, GXmlDomNode* child, GError** error) {
	GXmlGomNode * self;
	GXmlDomNode* result = NULL;
	GXmlDomNode* _tmp0_ = NULL;
	gboolean _tmp3_ = FALSE;
	GXmlDomNode* _tmp4_ = NULL;
	gboolean _tmp9_ = FALSE;
	gboolean _tmp10_ = FALSE;
	gboolean _tmp13_ = FALSE;
	gboolean _tmp14_ = FALSE;
	gboolean _tmp15_ = FALSE;
	gboolean _tmp16_ = FALSE;
	gboolean _tmp17_ = FALSE;
	GXmlDomNode* _tmp18_ = NULL;
	gboolean _tmp26_ = FALSE;
	gboolean _tmp27_ = FALSE;
	GXmlDomNode* _tmp28_ = NULL;
	gint i = 0;
	GXmlDomNodeList* _tmp33_ = NULL;
	GXmlDomNodeList* _tmp34_ = NULL;
	GXmlDomNodeList* _tmp35_ = NULL;
	GXmlDomNode* _tmp36_ = NULL;
	gint _tmp37_ = 0;
	gint _tmp38_ = 0;
	GXmlDomNodeList* _tmp39_ = NULL;
	GXmlDomNodeList* _tmp40_ = NULL;
	GXmlDomNodeList* _tmp41_ = NULL;
	gint _tmp42_ = 0;
	gpointer _tmp43_ = NULL;
	GXmlDomNode* _tmp44_ = NULL;
	gint _tmp45_ = 0;
	GXmlDomNodeList* _tmp46_ = NULL;
	GXmlDomNodeList* _tmp47_ = NULL;
	GXmlDomNodeList* _tmp48_ = NULL;
	gint _tmp49_ = 0;
	gint _tmp50_ = 0;
	gboolean _tmp51_ = FALSE;
	gint _tmp57_ = 0;
	GXmlDomNodeList* _tmp58_ = NULL;
	GXmlDomNodeList* _tmp59_ = NULL;
	GXmlDomNodeList* _tmp60_ = NULL;
	gint _tmp61_ = 0;
	gint _tmp62_ = 0;
	gboolean _tmp63_ = FALSE;
	GXmlDomNode* _tmp68_ = NULL;
	GXmlDomNode* _tmp69_ = NULL;
	GError * _inner_error_ = NULL;
	self = (GXmlGomNode*) base;
	g_return_val_if_fail (node != NULL, NULL);
	g_return_val_if_fail (child != NULL, NULL);
	_tmp0_ = node;
	if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GXML_TYPE_GNODE)) {
		const gchar* _tmp1_ = NULL;
		GError* _tmp2_ = NULL;
		_tmp1_ = _ ("Invalid attempt to add invalid node type");
		_tmp2_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_INVALID_NODE_TYPE_ERROR, _tmp1_);
		_inner_error_ = _tmp2_;
		g_propagate_error (error, _inner_error_);
		return NULL;
	}
	_tmp4_ = child;
	if (_tmp4_ == NULL) {
		_tmp3_ = TRUE;
	} else {
		GXmlDomNode* _tmp5_ = NULL;
		gboolean _tmp6_ = FALSE;
		_tmp5_ = child;
		_tmp6_ = gxml_dom_node_contains ((GXmlDomNode*) self, _tmp5_);
		_tmp3_ = !_tmp6_;
	}
	if (_tmp3_) {
		const gchar* _tmp7_ = NULL;
		GError* _tmp8_ = NULL;
		_tmp7_ = _ ("Can't find child node to replace or child have a different parent");
		_tmp8_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NOT_FOUND_ERROR, _tmp7_);
		_inner_error_ = _tmp8_;
		g_propagate_error (error, _inner_error_);
		return NULL;
	}
	if (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_DOCUMENT)) {
		_tmp10_ = TRUE;
	} else {
		_tmp10_ = G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_ELEMENT);
	}
	if (_tmp10_) {
		_tmp9_ = TRUE;
	} else {
		_tmp9_ = G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_DOCUMENT_FRAGMENT);
	}
	if (!_tmp9_) {
		const gchar* _tmp11_ = NULL;
		GError* _tmp12_ = NULL;
		_tmp11_ = _ ("Invalid attempt to insert a node");
		_tmp12_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_HIERARCHY_REQUEST_ERROR, _tmp11_);
		_inner_error_ = _tmp12_;
		g_propagate_error (error, _inner_error_);
		return NULL;
	}
	_tmp18_ = node;
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp18_, GXML_TYPE_DOM_DOCUMENT_FRAGMENT)) {
		_tmp17_ = TRUE;
	} else {
		GXmlDomNode* _tmp19_ = NULL;
		_tmp19_ = node;
		_tmp17_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp19_, GXML_TYPE_DOM_DOCUMENT_TYPE);
	}
	if (_tmp17_) {
		_tmp16_ = TRUE;
	} else {
		GXmlDomNode* _tmp20_ = NULL;
		_tmp20_ = node;
		_tmp16_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp20_, GXML_TYPE_DOM_ELEMENT);
	}
	if (_tmp16_) {
		_tmp15_ = TRUE;
	} else {
		GXmlDomNode* _tmp21_ = NULL;
		_tmp21_ = node;
		_tmp15_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp21_, GXML_TYPE_DOM_TEXT);
	}
	if (_tmp15_) {
		_tmp14_ = TRUE;
	} else {
		GXmlDomNode* _tmp22_ = NULL;
		_tmp22_ = node;
		_tmp14_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp22_, GXML_TYPE_DOM_PROCESSING_INSTRUCTION);
	}
	if (_tmp14_) {
		_tmp13_ = TRUE;
	} else {
		GXmlDomNode* _tmp23_ = NULL;
		_tmp23_ = node;
		_tmp13_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp23_, GXML_TYPE_DOM_COMMENT);
	}
	if (!_tmp13_) {
		const gchar* _tmp24_ = NULL;
		GError* _tmp25_ = NULL;
		_tmp24_ = _ ("Invalid attempt to insert an invalid node type");
		_tmp25_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_HIERARCHY_REQUEST_ERROR, _tmp24_);
		_inner_error_ = _tmp25_;
		g_propagate_error (error, _inner_error_);
		return NULL;
	}
	_tmp28_ = node;
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp28_, GXML_TYPE_DOM_TEXT)) {
		_tmp27_ = G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_DOCUMENT);
	} else {
		_tmp27_ = FALSE;
	}
	if (_tmp27_) {
		_tmp26_ = TRUE;
	} else {
		gboolean _tmp29_ = FALSE;
		GXmlDomNode* _tmp30_ = NULL;
		_tmp30_ = node;
		if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp30_, GXML_TYPE_DOM_DOCUMENT_TYPE)) {
			_tmp29_ = !G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_DOCUMENT);
		} else {
			_tmp29_ = FALSE;
		}
		_tmp26_ = _tmp29_;
	}
	if (_tmp26_) {
		const gchar* _tmp31_ = NULL;
		GError* _tmp32_ = NULL;
		_tmp31_ = _ ("Invalid attempt to insert a document's type or text node to an invalid" \
" parent");
		_tmp32_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_HIERARCHY_REQUEST_ERROR, _tmp31_);
		_inner_error_ = _tmp32_;
		g_propagate_error (error, _inner_error_);
		return NULL;
	}
	_tmp33_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
	_tmp34_ = _tmp33_;
	_tmp35_ = _tmp34_;
	_tmp36_ = child;
	_tmp37_ = gee_list_index_of ((GeeList*) _tmp35_, G_TYPE_CHECK_INSTANCE_TYPE (_tmp36_, GXML_TYPE_DOM_NODE) ? ((GXmlDomNode*) _tmp36_) : NULL);
	_tmp38_ = _tmp37_;
	_g_object_unref0 (_tmp35_);
	i = _tmp38_;
	_tmp39_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
	_tmp40_ = _tmp39_;
	_tmp41_ = _tmp40_;
	_tmp42_ = i;
	_tmp43_ = gee_list_remove_at ((GeeList*) _tmp41_, _tmp42_);
	_tmp44_ = (GXmlDomNode*) _tmp43_;
	_g_object_unref0 (_tmp44_);
	_g_object_unref0 (_tmp41_);
	_tmp45_ = i;
	_tmp46_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
	_tmp47_ = _tmp46_;
	_tmp48_ = _tmp47_;
	_tmp49_ = gee_collection_get_size ((GeeCollection*) _tmp48_);
	_tmp50_ = _tmp49_;
	_tmp51_ = _tmp45_ < _tmp50_;
	_g_object_unref0 (_tmp48_);
	if (_tmp51_) {
		GXmlDomNodeList* _tmp52_ = NULL;
		GXmlDomNodeList* _tmp53_ = NULL;
		GXmlDomNodeList* _tmp54_ = NULL;
		gint _tmp55_ = 0;
		GXmlDomNode* _tmp56_ = NULL;
		_tmp52_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
		_tmp53_ = _tmp52_;
		_tmp54_ = _tmp53_;
		_tmp55_ = i;
		_tmp56_ = node;
		gee_list_insert ((GeeList*) _tmp54_, _tmp55_, G_TYPE_CHECK_INSTANCE_TYPE (_tmp56_, GXML_TYPE_DOM_NODE) ? ((GXmlDomNode*) _tmp56_) : NULL);
		_g_object_unref0 (_tmp54_);
	}
	_tmp57_ = i;
	_tmp58_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
	_tmp59_ = _tmp58_;
	_tmp60_ = _tmp59_;
	_tmp61_ = gee_collection_get_size ((GeeCollection*) _tmp60_);
	_tmp62_ = _tmp61_;
	_tmp63_ = _tmp57_ >= _tmp62_;
	_g_object_unref0 (_tmp60_);
	if (_tmp63_) {
		GXmlDomNodeList* _tmp64_ = NULL;
		GXmlDomNodeList* _tmp65_ = NULL;
		GXmlDomNodeList* _tmp66_ = NULL;
		GXmlDomNode* _tmp67_ = NULL;
		_tmp64_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
		_tmp65_ = _tmp64_;
		_tmp66_ = _tmp65_;
		_tmp67_ = node;
		gee_collection_add ((GeeCollection*) _tmp66_, _tmp67_);
		_g_object_unref0 (_tmp66_);
	}
	_tmp68_ = child;
	_tmp69_ = _g_object_ref0 (_tmp68_);
	result = _tmp69_;
	return result;
}


static GXmlDomNode* gxml_gom_node_real_remove_child (GXmlDomNode* base, GXmlDomNode* child, GError** error) {
	GXmlGomNode * self;
	GXmlDomNode* result = NULL;
	GXmlDomNode* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gint i = 0;
	GXmlDomNodeList* _tmp4_ = NULL;
	GXmlDomNodeList* _tmp5_ = NULL;
	GXmlDomNodeList* _tmp6_ = NULL;
	GXmlDomNode* _tmp7_ = NULL;
	gint _tmp8_ = 0;
	gint _tmp9_ = 0;
	GXmlDomNodeList* _tmp10_ = NULL;
	GXmlDomNodeList* _tmp11_ = NULL;
	GXmlDomNodeList* _tmp12_ = NULL;
	gpointer _tmp13_ = NULL;
	GXmlDomNode* _tmp14_ = NULL;
	GError * _inner_error_ = NULL;
	self = (GXmlGomNode*) base;
	g_return_val_if_fail (child != NULL, NULL);
	_tmp0_ = child;
	_tmp1_ = gxml_dom_node_contains ((GXmlDomNode*) self, _tmp0_);
	if (!_tmp1_) {
		const gchar* _tmp2_ = NULL;
		GError* _tmp3_ = NULL;
		_tmp2_ = _ ("Can't find child node to remove or child have a different parent");
		_tmp3_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NOT_FOUND_ERROR, _tmp2_);
		_inner_error_ = _tmp3_;
		g_propagate_error (error, _inner_error_);
		return NULL;
	}
	_tmp4_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
	_tmp5_ = _tmp4_;
	_tmp6_ = _tmp5_;
	_tmp7_ = child;
	_tmp8_ = gee_list_index_of ((GeeList*) _tmp6_, G_TYPE_CHECK_INSTANCE_TYPE (_tmp7_, GXML_TYPE_DOM_NODE) ? ((GXmlDomNode*) _tmp7_) : NULL);
	_tmp9_ = _tmp8_;
	_g_object_unref0 (_tmp6_);
	i = _tmp9_;
	_tmp10_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
	_tmp11_ = _tmp10_;
	_tmp12_ = _tmp11_;
	_tmp13_ = gee_list_remove_at ((GeeList*) _tmp12_, i);
	_tmp14_ = G_TYPE_CHECK_INSTANCE_CAST ((GXmlDomNode*) _tmp13_, GXML_TYPE_DOM_NODE, GXmlDomNode);
	_g_object_unref0 (_tmp12_);
	result = _tmp14_;
	return result;
}


static void gxml_gom_node_real_add_event_listener (GXmlDomEventTarget* base, const gchar* type, GXmlDomEventListener* callback, gboolean capture) {
	GXmlGomNode * self;
	self = (GXmlGomNode*) base;
	g_return_if_fail (type != NULL);
	return;
}


static void gxml_gom_node_real_remove_event_listener (GXmlDomEventTarget* base, const gchar* type, GXmlDomEventListener* callback, gboolean capture) {
	GXmlGomNode * self;
	self = (GXmlGomNode*) base;
	g_return_if_fail (type != NULL);
	return;
}


static gboolean gxml_gom_node_real_dispatch_event (GXmlDomEventTarget* base, GXmlDomEvent* event, GError** error) {
	GXmlGomNode * self;
	gboolean result = FALSE;
	self = (GXmlGomNode*) base;
	g_return_val_if_fail (event != NULL, FALSE);
	result = FALSE;
	return result;
}


GXmlGomNode* gxml_gom_node_construct (GType object_type) {
	GXmlGomNode * self = NULL;
	self = (GXmlGomNode*) g_object_new (object_type, NULL);
	return self;
}


GXmlGomNode* gxml_gom_node_new (void) {
	return gxml_gom_node_construct (GXML_TYPE_GOM_NODE);
}


static GXmlDomNodeNodeType gxml_gom_node_real_get_node_type (GXmlDomNode* base) {
	GXmlDomNodeNodeType result;
	GXmlGomNode* self;
	GXmlDomNodeNodeType _tmp0_ = 0;
	self = (GXmlGomNode*) base;
	_tmp0_ = self->_node_type;
	result = _tmp0_;
	return result;
}


static gchar* gxml_gom_node_real_get_node_name (GXmlDomNode* base) {
	gchar* result;
	GXmlGomNode* self;
	const gchar* _tmp0_ = NULL;
	gboolean _tmp2_ = FALSE;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	const gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	gchar* _tmp12_ = NULL;
	self = (GXmlGomNode*) base;
	_tmp0_ = self->_local_name;
	if (_tmp0_ == NULL) {
		gchar* _tmp1_ = NULL;
		_tmp1_ = g_strdup ("NO NAME");
		result = _tmp1_;
		return result;
	}
	_tmp3_ = self->_prefix;
	if (_tmp3_ == NULL) {
		_tmp2_ = TRUE;
	} else {
		const gchar* _tmp4_ = NULL;
		_tmp4_ = self->_prefix;
		_tmp2_ = g_strcmp0 (_tmp4_, "") == 0;
	}
	if (_tmp2_) {
		const gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		_tmp5_ = self->_local_name;
		_tmp6_ = g_strdup (_tmp5_);
		result = _tmp6_;
		return result;
	}
	_tmp7_ = self->_prefix;
	_tmp8_ = g_strconcat (_tmp7_, ":", NULL);
	_tmp9_ = _tmp8_;
	_tmp10_ = self->_local_name;
	_tmp11_ = g_strconcat (_tmp9_, _tmp10_, NULL);
	_tmp12_ = _tmp11_;
	_g_free0 (_tmp9_);
	result = _tmp12_;
	return result;
}


static const gchar* gxml_gom_node_real_get_base_uri (GXmlDomNode* base) {
	const gchar* result;
	GXmlGomNode* self;
	const gchar* _tmp0_ = NULL;
	self = (GXmlGomNode*) base;
	_tmp0_ = self->_base_uri;
	result = _tmp0_;
	return result;
}


static GXmlDomDocument* gxml_gom_node_real_get_owner_document (GXmlDomNode* base) {
	GXmlDomDocument* result;
	GXmlGomNode* self;
	GXmlDomDocument* _tmp0_ = NULL;
	GXmlDomDocument* _tmp7_ = NULL;
	GError * _inner_error_ = NULL;
	self = (GXmlGomNode*) base;
	if (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_DOCUMENT)) {
		result = G_TYPE_CHECK_INSTANCE_CAST (self, GXML_TYPE_DOM_DOCUMENT, GXmlDomDocument);
		return result;
	}
	_tmp0_ = self->_document;
	if (_tmp0_ == NULL) {
		GXmlGomDocument* _tmp1_ = NULL;
		_tmp1_ = gxml_gom_document_new ();
		_g_object_unref0 (self->_document);
		self->_document = (GXmlDomDocument*) _tmp1_;
		if (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_ELEMENT)) {
			{
				GXmlDomDocument* _tmp2_ = NULL;
				GXmlDomNode* _tmp3_ = NULL;
				GXmlDomNode* _tmp4_ = NULL;
				_tmp2_ = self->_document;
				_tmp3_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp2_, (GXmlDomNode*) self, &_inner_error_);
				_tmp4_ = _tmp3_;
				_g_object_unref0 (_tmp4_);
				if (G_UNLIKELY (_inner_error_ != NULL)) {
					goto __catch18_g_error;
				}
			}
			goto __finally18;
			__catch18_g_error:
			{
				GError* e = NULL;
				GError* _tmp5_ = NULL;
				const gchar* _tmp6_ = NULL;
				e = _inner_error_;
				_inner_error_ = NULL;
				_tmp5_ = e;
				_tmp6_ = _tmp5_->message;
				g_warning ("GomNode.vala:79: %s", _tmp6_);
				_g_error_free0 (e);
			}
			__finally18:
			if (G_UNLIKELY (_inner_error_ != NULL)) {
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
				g_clear_error (&_inner_error_);
				return NULL;
			}
		}
	}
	_tmp7_ = self->_document;
	result = _tmp7_;
	return result;
}


static void gxml_gom_node_real_set_owner_document (GXmlDomNode* base, GXmlDomDocument* value) {
	GXmlGomNode* self;
	GXmlDomDocument* _tmp0_ = NULL;
	GXmlDomDocument* _tmp1_ = NULL;
	self = (GXmlGomNode*) base;
	_tmp0_ = value;
	_tmp1_ = _g_object_ref0 (_tmp0_);
	_g_object_unref0 (self->_document);
	self->_document = _tmp1_;
	g_object_notify ((GObject *) self, "owner-document");
}


static GXmlDomNode* gxml_gom_node_real_get_parent_node (GXmlDomNode* base) {
	GXmlDomNode* result;
	GXmlGomNode* self;
	GXmlDomNode* _tmp0_ = NULL;
	GXmlDomNode* _tmp1_ = NULL;
	self = (GXmlGomNode*) base;
	_tmp0_ = self->_parent;
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GXML_TYPE_DOM_NODE) ? ((GXmlDomNode*) _tmp0_) : NULL);
	result = _tmp1_;
	return result;
}


static GXmlDomElement* gxml_gom_node_real_get_parent_element (GXmlDomNode* base) {
	GXmlDomElement* result;
	GXmlGomNode* self;
	GXmlDomNode* _tmp0_ = NULL;
	self = (GXmlGomNode*) base;
	_tmp0_ = self->_parent;
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GXML_TYPE_DOM_ELEMENT)) {
		GXmlDomNode* _tmp1_ = NULL;
		GXmlDomElement* _tmp2_ = NULL;
		_tmp1_ = self->_parent;
		_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp1_) : NULL);
		result = _tmp2_;
		return result;
	}
	result = NULL;
	return result;
}


static GXmlDomNodeList* gxml_gom_node_real_get_child_nodes (GXmlDomNode* base) {
	GXmlDomNodeList* result;
	GXmlGomNode* self;
	GXmlGomNodeList* _tmp0_ = NULL;
	GXmlDomNodeList* _tmp1_ = NULL;
	self = (GXmlGomNode*) base;
	_tmp0_ = self->_child_nodes;
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GXML_TYPE_DOM_NODE_LIST) ? ((GXmlDomNodeList*) _tmp0_) : NULL);
	result = _tmp1_;
	return result;
}


static GXmlDomNode* gxml_gom_node_real_get_first_child (GXmlDomNode* base) {
	GXmlDomNode* result;
	GXmlGomNode* self;
	GXmlDomNodeList* _tmp0_ = NULL;
	GXmlDomNodeList* _tmp1_ = NULL;
	GXmlDomNodeList* _tmp2_ = NULL;
	gint _tmp3_ = 0;
	gint _tmp4_ = 0;
	gboolean _tmp5_ = FALSE;
	GXmlDomNodeList* _tmp6_ = NULL;
	GXmlDomNodeList* _tmp7_ = NULL;
	GXmlDomNodeList* _tmp8_ = NULL;
	gpointer _tmp9_ = NULL;
	GXmlDomNode* _tmp10_ = NULL;
	self = (GXmlGomNode*) base;
	_tmp0_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	_tmp3_ = gee_collection_get_size ((GeeCollection*) _tmp2_);
	_tmp4_ = _tmp3_;
	_tmp5_ = _tmp4_ == 0;
	_g_object_unref0 (_tmp2_);
	if (_tmp5_) {
		result = NULL;
		return result;
	}
	_tmp6_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
	_tmp7_ = _tmp6_;
	_tmp8_ = _tmp7_;
	_tmp9_ = gee_list_get ((GeeList*) _tmp8_, 0);
	_tmp10_ = (GXmlDomNode*) _tmp9_;
	_g_object_unref0 (_tmp8_);
	result = _tmp10_;
	return result;
}


static GXmlDomNode* gxml_gom_node_real_get_last_child (GXmlDomNode* base) {
	GXmlDomNode* result;
	GXmlGomNode* self;
	GXmlDomNodeList* _tmp0_ = NULL;
	GXmlDomNodeList* _tmp1_ = NULL;
	GXmlDomNodeList* _tmp2_ = NULL;
	gint _tmp3_ = 0;
	gint _tmp4_ = 0;
	gboolean _tmp5_ = FALSE;
	GXmlDomNodeList* _tmp6_ = NULL;
	GXmlDomNodeList* _tmp7_ = NULL;
	GXmlDomNodeList* _tmp8_ = NULL;
	GXmlDomNodeList* _tmp9_ = NULL;
	GXmlDomNodeList* _tmp10_ = NULL;
	GXmlDomNodeList* _tmp11_ = NULL;
	gint _tmp12_ = 0;
	gint _tmp13_ = 0;
	gpointer _tmp14_ = NULL;
	GXmlDomNode* _tmp15_ = NULL;
	self = (GXmlGomNode*) base;
	_tmp0_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	_tmp3_ = gee_collection_get_size ((GeeCollection*) _tmp2_);
	_tmp4_ = _tmp3_;
	_tmp5_ = _tmp4_ == 0;
	_g_object_unref0 (_tmp2_);
	if (_tmp5_) {
		result = NULL;
		return result;
	}
	_tmp6_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
	_tmp7_ = _tmp6_;
	_tmp8_ = _tmp7_;
	_tmp9_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
	_tmp10_ = _tmp9_;
	_tmp11_ = _tmp10_;
	_tmp12_ = gee_collection_get_size ((GeeCollection*) _tmp11_);
	_tmp13_ = _tmp12_;
	_tmp14_ = gee_list_get ((GeeList*) _tmp8_, _tmp13_ - 1);
	_tmp15_ = (GXmlDomNode*) _tmp14_;
	_g_object_unref0 (_tmp11_);
	_g_object_unref0 (_tmp8_);
	result = _tmp15_;
	return result;
}


static GXmlDomNode* gxml_gom_node_real_get_previous_sibling (GXmlDomNode* base) {
	GXmlDomNode* result;
	GXmlGomNode* self;
	GXmlDomNode* _tmp0_ = NULL;
	GXmlDomNode* _tmp1_ = NULL;
	GXmlDomNodeList* _tmp2_ = NULL;
	GXmlDomNodeList* _tmp3_ = NULL;
	GXmlDomNodeList* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
	GXmlDomNode* _tmp6_ = NULL;
	GXmlDomNodeList* _tmp7_ = NULL;
	GXmlDomNodeList* _tmp8_ = NULL;
	GXmlDomNodeList* _tmp9_ = NULL;
	gint _tmp10_ = 0;
	gint _tmp11_ = 0;
	gboolean _tmp12_ = FALSE;
	gint pos = 0;
	GXmlDomNode* _tmp13_ = NULL;
	GXmlDomNodeList* _tmp14_ = NULL;
	GXmlDomNodeList* _tmp15_ = NULL;
	GeeArrayList* _tmp16_ = NULL;
	GeeArrayList* _tmp17_ = NULL;
	gint _tmp18_ = 0;
	gint _tmp19_ = 0;
	gint _tmp20_ = 0;
	gboolean _tmp21_ = FALSE;
	gint _tmp22_ = 0;
	self = (GXmlGomNode*) base;
	_tmp0_ = self->_parent;
	if (_tmp0_ == NULL) {
		result = NULL;
		return result;
	}
	_tmp1_ = self->_parent;
	_tmp2_ = gxml_dom_node_get_child_nodes (_tmp1_);
	_tmp3_ = _tmp2_;
	_tmp4_ = _tmp3_;
	_tmp5_ = _tmp4_ == NULL;
	_g_object_unref0 (_tmp4_);
	if (_tmp5_) {
		result = NULL;
		return result;
	}
	_tmp6_ = self->_parent;
	_tmp7_ = gxml_dom_node_get_child_nodes (_tmp6_);
	_tmp8_ = _tmp7_;
	_tmp9_ = _tmp8_;
	_tmp10_ = gxml_dom_node_list_get_length (_tmp9_);
	_tmp11_ = _tmp10_;
	_tmp12_ = _tmp11_ == 0;
	_g_object_unref0 (_tmp9_);
	if (_tmp12_) {
		result = NULL;
		return result;
	}
	_tmp13_ = self->_parent;
	_tmp14_ = gxml_dom_node_get_child_nodes (_tmp13_);
	_tmp15_ = _tmp14_;
	_tmp16_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp15_, GEE_TYPE_ARRAY_LIST) ? ((GeeArrayList*) _tmp15_) : NULL;
	if (_tmp16_ == NULL) {
		_g_object_unref0 (_tmp15_);
	}
	_tmp17_ = _tmp16_;
	_tmp18_ = gee_abstract_list_index_of ((GeeAbstractList*) _tmp17_, (GXmlDomNode*) self);
	_tmp19_ = _tmp18_;
	_g_object_unref0 (_tmp17_);
	pos = _tmp19_;
	_tmp20_ = pos;
	if (_tmp20_ == 0) {
		result = NULL;
		return result;
	}
	_tmp22_ = pos;
	if ((_tmp22_ - 1) > 0) {
		gint _tmp23_ = 0;
		GXmlDomNode* _tmp24_ = NULL;
		GXmlDomNodeList* _tmp25_ = NULL;
		GXmlDomNodeList* _tmp26_ = NULL;
		GXmlDomNodeList* _tmp27_ = NULL;
		gint _tmp28_ = 0;
		gint _tmp29_ = 0;
		_tmp23_ = pos;
		_tmp24_ = self->_parent;
		_tmp25_ = gxml_dom_node_get_child_nodes (_tmp24_);
		_tmp26_ = _tmp25_;
		_tmp27_ = _tmp26_;
		_tmp28_ = gee_collection_get_size ((GeeCollection*) _tmp27_);
		_tmp29_ = _tmp28_;
		_tmp21_ = (_tmp23_ - 1) < _tmp29_;
		_g_object_unref0 (_tmp27_);
	} else {
		_tmp21_ = FALSE;
	}
	if (_tmp21_) {
		GXmlDomNode* _tmp30_ = NULL;
		GXmlDomNodeList* _tmp31_ = NULL;
		GXmlDomNodeList* _tmp32_ = NULL;
		GXmlDomNodeList* _tmp33_ = NULL;
		gint _tmp34_ = 0;
		gpointer _tmp35_ = NULL;
		GXmlDomNode* _tmp36_ = NULL;
		_tmp30_ = self->_parent;
		_tmp31_ = gxml_dom_node_get_child_nodes (_tmp30_);
		_tmp32_ = _tmp31_;
		_tmp33_ = _tmp32_;
		_tmp34_ = pos;
		_tmp35_ = gee_list_get ((GeeList*) _tmp33_, _tmp34_ - 1);
		_tmp36_ = (GXmlDomNode*) _tmp35_;
		_g_object_unref0 (_tmp33_);
		result = _tmp36_;
		return result;
	}
	result = NULL;
	return result;
}


static GXmlDomNode* gxml_gom_node_real_get_next_sibling (GXmlDomNode* base) {
	GXmlDomNode* result;
	GXmlGomNode* self;
	GXmlDomNode* _tmp0_ = NULL;
	GXmlDomNode* _tmp1_ = NULL;
	GXmlDomNodeList* _tmp2_ = NULL;
	GXmlDomNodeList* _tmp3_ = NULL;
	GXmlDomNodeList* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
	GXmlDomNode* _tmp6_ = NULL;
	GXmlDomNodeList* _tmp7_ = NULL;
	GXmlDomNodeList* _tmp8_ = NULL;
	GXmlDomNodeList* _tmp9_ = NULL;
	gint _tmp10_ = 0;
	gint _tmp11_ = 0;
	gboolean _tmp12_ = FALSE;
	gint pos = 0;
	GXmlDomNode* _tmp13_ = NULL;
	GXmlDomNodeList* _tmp14_ = NULL;
	GXmlDomNodeList* _tmp15_ = NULL;
	GeeArrayList* _tmp16_ = NULL;
	GeeArrayList* _tmp17_ = NULL;
	gint _tmp18_ = 0;
	gint _tmp19_ = 0;
	gint _tmp20_ = 0;
	gboolean _tmp21_ = FALSE;
	gint _tmp22_ = 0;
	self = (GXmlGomNode*) base;
	_tmp0_ = self->_parent;
	if (_tmp0_ == NULL) {
		result = NULL;
		return result;
	}
	_tmp1_ = self->_parent;
	_tmp2_ = gxml_dom_node_get_child_nodes (_tmp1_);
	_tmp3_ = _tmp2_;
	_tmp4_ = _tmp3_;
	_tmp5_ = _tmp4_ == NULL;
	_g_object_unref0 (_tmp4_);
	if (_tmp5_) {
		result = NULL;
		return result;
	}
	_tmp6_ = self->_parent;
	_tmp7_ = gxml_dom_node_get_child_nodes (_tmp6_);
	_tmp8_ = _tmp7_;
	_tmp9_ = _tmp8_;
	_tmp10_ = gxml_dom_node_list_get_length (_tmp9_);
	_tmp11_ = _tmp10_;
	_tmp12_ = _tmp11_ == 0;
	_g_object_unref0 (_tmp9_);
	if (_tmp12_) {
		result = NULL;
		return result;
	}
	_tmp13_ = self->_parent;
	_tmp14_ = gxml_dom_node_get_child_nodes (_tmp13_);
	_tmp15_ = _tmp14_;
	_tmp16_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp15_, GEE_TYPE_ARRAY_LIST) ? ((GeeArrayList*) _tmp15_) : NULL;
	if (_tmp16_ == NULL) {
		_g_object_unref0 (_tmp15_);
	}
	_tmp17_ = _tmp16_;
	_tmp18_ = gee_abstract_list_index_of ((GeeAbstractList*) _tmp17_, (GXmlDomNode*) self);
	_tmp19_ = _tmp18_;
	_g_object_unref0 (_tmp17_);
	pos = _tmp19_;
	_tmp20_ = pos;
	if (_tmp20_ == 0) {
		result = NULL;
		return result;
	}
	_tmp22_ = pos;
	if ((_tmp22_ + 1) > 0) {
		gint _tmp23_ = 0;
		GXmlDomNode* _tmp24_ = NULL;
		GXmlDomNodeList* _tmp25_ = NULL;
		GXmlDomNodeList* _tmp26_ = NULL;
		GXmlDomNodeList* _tmp27_ = NULL;
		gint _tmp28_ = 0;
		gint _tmp29_ = 0;
		_tmp23_ = pos;
		_tmp24_ = self->_parent;
		_tmp25_ = gxml_dom_node_get_child_nodes (_tmp24_);
		_tmp26_ = _tmp25_;
		_tmp27_ = _tmp26_;
		_tmp28_ = gee_collection_get_size ((GeeCollection*) _tmp27_);
		_tmp29_ = _tmp28_;
		_tmp21_ = (_tmp23_ + 1) < _tmp29_;
		_g_object_unref0 (_tmp27_);
	} else {
		_tmp21_ = FALSE;
	}
	if (_tmp21_) {
		GXmlDomNode* _tmp30_ = NULL;
		GXmlDomNodeList* _tmp31_ = NULL;
		GXmlDomNodeList* _tmp32_ = NULL;
		GXmlDomNodeList* _tmp33_ = NULL;
		gint _tmp34_ = 0;
		gpointer _tmp35_ = NULL;
		GXmlDomNode* _tmp36_ = NULL;
		_tmp30_ = self->_parent;
		_tmp31_ = gxml_dom_node_get_child_nodes (_tmp30_);
		_tmp32_ = _tmp31_;
		_tmp33_ = _tmp32_;
		_tmp34_ = pos;
		_tmp35_ = gee_list_get ((GeeList*) _tmp33_, _tmp34_ + 1);
		_tmp36_ = (GXmlDomNode*) _tmp35_;
		_g_object_unref0 (_tmp33_);
		result = _tmp36_;
		return result;
	}
	result = NULL;
	return result;
}


static gchar* gxml_gom_node_real_get_node_value (GXmlDomNode* base) {
	gchar* result;
	GXmlGomNode* self;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	self = (GXmlGomNode*) base;
	_tmp0_ = self->_node_value;
	_tmp1_ = g_strdup (_tmp0_);
	result = _tmp1_;
	return result;
}


static void gxml_gom_node_real_set_node_value (GXmlDomNode* base, const gchar* value) {
	GXmlGomNode* self;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	self = (GXmlGomNode*) base;
	_tmp0_ = value;
	_tmp1_ = g_strdup (_tmp0_);
	_g_free0 (self->_node_value);
	self->_node_value = _tmp1_;
	g_object_notify ((GObject *) self, "node-value");
}


static gchar* gxml_gom_node_real_get_text_content (GXmlDomNode* base) {
	gchar* result;
	GXmlGomNode* self;
	gchar* t = NULL;
	self = (GXmlGomNode*) base;
	t = NULL;
	{
		GXmlDomNodeList* _n_list = NULL;
		GXmlDomNodeList* _tmp0_ = NULL;
		GXmlDomNodeList* _tmp1_ = NULL;
		gint _n_size = 0;
		GXmlDomNodeList* _tmp2_ = NULL;
		gint _tmp3_ = 0;
		gint _tmp4_ = 0;
		gint _n_index = 0;
		_tmp0_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
		_tmp1_ = _tmp0_;
		_n_list = _tmp1_;
		_tmp2_ = _n_list;
		_tmp3_ = gee_collection_get_size ((GeeCollection*) _tmp2_);
		_tmp4_ = _tmp3_;
		_n_size = _tmp4_;
		_n_index = -1;
		while (TRUE) {
			gint _tmp5_ = 0;
			gint _tmp6_ = 0;
			gint _tmp7_ = 0;
			GXmlDomNode* n = NULL;
			GXmlDomNodeList* _tmp8_ = NULL;
			gint _tmp9_ = 0;
			gpointer _tmp10_ = NULL;
			GXmlDomNode* _tmp11_ = NULL;
			_tmp5_ = _n_index;
			_n_index = _tmp5_ + 1;
			_tmp6_ = _n_index;
			_tmp7_ = _n_size;
			if (!(_tmp6_ < _tmp7_)) {
				break;
			}
			_tmp8_ = _n_list;
			_tmp9_ = _n_index;
			_tmp10_ = gee_list_get ((GeeList*) _tmp8_, _tmp9_);
			n = (GXmlDomNode*) _tmp10_;
			_tmp11_ = n;
			if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp11_, GXML_TYPE_DOM_TEXT)) {
				const gchar* _tmp12_ = NULL;
				_tmp12_ = t;
				if (_tmp12_ == NULL) {
					GXmlDomNode* _tmp13_ = NULL;
					gchar* _tmp14_ = NULL;
					gchar* _tmp15_ = NULL;
					_tmp13_ = n;
					_tmp14_ = gxml_dom_node_get_node_value (_tmp13_);
					_tmp15_ = _tmp14_;
					_g_free0 (t);
					t = _tmp15_;
				} else {
					const gchar* _tmp16_ = NULL;
					GXmlDomNode* _tmp17_ = NULL;
					gchar* _tmp18_ = NULL;
					gchar* _tmp19_ = NULL;
					gchar* _tmp20_ = NULL;
					gchar* _tmp21_ = NULL;
					_tmp16_ = t;
					_tmp17_ = n;
					_tmp18_ = gxml_dom_node_get_node_value (_tmp17_);
					_tmp19_ = _tmp18_;
					_tmp20_ = _tmp19_;
					_tmp21_ = g_strconcat (_tmp16_, _tmp20_, NULL);
					_g_free0 (t);
					t = _tmp21_;
					_g_free0 (_tmp20_);
				}
			}
			_g_object_unref0 (n);
		}
		_g_object_unref0 (_n_list);
	}
	result = t;
	return result;
}


static void gxml_gom_node_real_set_text_content (GXmlDomNode* base, const gchar* value) {
	GXmlGomNode* self;
	GError * _inner_error_ = NULL;
	self = (GXmlGomNode*) base;
	{
		GXmlDomText* t = NULL;
		GXmlDomDocument* _tmp0_ = NULL;
		const gchar* _tmp1_ = NULL;
		GXmlDomText* _tmp2_ = NULL;
		GXmlDomNodeList* _tmp3_ = NULL;
		GXmlDomNodeList* _tmp4_ = NULL;
		GXmlDomNodeList* _tmp5_ = NULL;
		_tmp0_ = self->_document;
		_tmp1_ = value;
		_tmp2_ = gxml_dom_document_create_text_node (_tmp0_, _tmp1_, &_inner_error_);
		t = _tmp2_;
		if (G_UNLIKELY (_inner_error_ != NULL)) {
			goto __catch19_g_error;
		}
		_tmp3_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
		_tmp4_ = _tmp3_;
		_tmp5_ = _tmp4_;
		gee_collection_add ((GeeCollection*) _tmp5_, (GXmlDomNode*) t);
		_g_object_unref0 (_tmp5_);
		_g_object_unref0 (t);
	}
	goto __finally19;
	__catch19_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp6_ = NULL;
		e = _inner_error_;
		_inner_error_ = NULL;
		_tmp6_ = _ ("Text content in element can't be created");
		g_warning ("GomNode.vala:150: %s", _tmp6_);
		_g_error_free0 (e);
	}
	__finally19:
	if (G_UNLIKELY (_inner_error_ != NULL)) {
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
		g_clear_error (&_inner_error_);
		return;
	}
	g_object_notify ((GObject *) self, "text-content");
}


static GObject * gxml_gom_node_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GXmlGomNode * self;
	gchar* _tmp0_ = NULL;
	GXmlGomNodeList* _tmp1_ = NULL;
	parent_class = G_OBJECT_CLASS (gxml_gom_node_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GXML_TYPE_GOM_NODE, GXmlGomNode);
	_tmp0_ = g_strdup ("");
	_g_free0 (self->_local_name);
	self->_local_name = _tmp0_;
	_g_free0 (self->_prefix);
	self->_prefix = NULL;
	self->_node_type = GXML_DOM_NODE_NODE_TYPE_INVALID;
	_g_free0 (self->_base_uri);
	self->_base_uri = NULL;
	_g_free0 (self->_node_value);
	self->_node_value = NULL;
	_tmp1_ = gxml_gom_node_list_new ();
	_g_object_unref0 (self->_child_nodes);
	self->_child_nodes = _tmp1_;
	_g_object_unref0 (self->_parent);
	self->_parent = NULL;
	return obj;
}


static void gxml_gom_node_class_init (GXmlGomNodeClass * klass) {
	gxml_gom_node_parent_class = g_type_class_peek_parent (klass);
	G_OBJECT_CLASS (klass)->get_property = _vala_gxml_gom_node_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_gxml_gom_node_set_property;
	G_OBJECT_CLASS (klass)->constructor = gxml_gom_node_constructor;
	G_OBJECT_CLASS (klass)->finalize = gxml_gom_node_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_NODE_NODE_TYPE, g_param_spec_enum ("node-type", "node-type", "node-type", GXML_DOM_NODE_TYPE_NODE_TYPE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_NODE_NODE_NAME, g_param_spec_string ("node-name", "node-name", "node-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_NODE_BASE_URI, g_param_spec_string ("base-uri", "base-uri", "base-uri", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_NODE_OWNER_DOCUMENT, g_param_spec_object ("owner-document", "owner-document", "owner-document", GXML_TYPE_DOM_DOCUMENT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_NODE_PARENT_NODE, g_param_spec_object ("parent-node", "parent-node", "parent-node", GXML_TYPE_DOM_NODE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_NODE_PARENT_ELEMENT, g_param_spec_object ("parent-element", "parent-element", "parent-element", GXML_TYPE_DOM_ELEMENT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_NODE_CHILD_NODES, g_param_spec_object ("child-nodes", "child-nodes", "child-nodes", GXML_TYPE_DOM_NODE_LIST, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_NODE_FIRST_CHILD, g_param_spec_object ("first-child", "first-child", "first-child", GXML_TYPE_DOM_NODE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_NODE_LAST_CHILD, g_param_spec_object ("last-child", "last-child", "last-child", GXML_TYPE_DOM_NODE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_NODE_PREVIOUS_SIBLING, g_param_spec_object ("previous-sibling", "previous-sibling", "previous-sibling", GXML_TYPE_DOM_NODE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_NODE_NEXT_SIBLING, g_param_spec_object ("next-sibling", "next-sibling", "next-sibling", GXML_TYPE_DOM_NODE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_NODE_NODE_VALUE, g_param_spec_string ("node-value", "node-value", "node-value", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_NODE_TEXT_CONTENT, g_param_spec_string ("text-content", "text-content", "text-content", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
}


static void gxml_gom_node_gxml_dom_event_target_interface_init (GXmlDomEventTargetIface * iface) {
	gxml_gom_node_gxml_dom_event_target_parent_iface = g_type_interface_peek_parent (iface);
	iface->add_event_listener = (void (*)(GXmlDomEventTarget*, const gchar*, GXmlDomEventListener*, gboolean)) gxml_gom_node_real_add_event_listener;
	iface->remove_event_listener = (void (*)(GXmlDomEventTarget*, const gchar*, GXmlDomEventListener*, gboolean)) gxml_gom_node_real_remove_event_listener;
	iface->dispatch_event = (gboolean (*)(GXmlDomEventTarget*, GXmlDomEvent*, GError**)) gxml_gom_node_real_dispatch_event;
}


static void gxml_gom_node_gxml_dom_node_interface_init (GXmlDomNodeIface * iface) {
	gxml_gom_node_gxml_dom_node_parent_iface = g_type_interface_peek_parent (iface);
	iface->has_child_nodes = (gboolean (*)(GXmlDomNode*)) gxml_gom_node_real_has_child_nodes;
	iface->normalize = (void (*)(GXmlDomNode*)) gxml_gom_node_real_normalize;
	iface->is_equal_node = (gboolean (*)(GXmlDomNode*, GXmlDomNode*)) gxml_gom_node_real_is_equal_node;
	iface->compare_document_position = (GXmlDomNodeDocumentPosition (*)(GXmlDomNode*, GXmlDomNode*)) gxml_gom_node_real_compare_document_position;
	iface->contains = (gboolean (*)(GXmlDomNode*, GXmlDomNode*)) gxml_gom_node_real_contains;
	iface->lookup_prefix = (gchar* (*)(GXmlDomNode*, const gchar*)) gxml_gom_node_real_lookup_prefix;
	iface->lookup_namespace_uri = (gchar* (*)(GXmlDomNode*, const gchar*)) gxml_gom_node_real_lookup_namespace_uri;
	iface->is_default_namespace = (gboolean (*)(GXmlDomNode*, const gchar*)) gxml_gom_node_real_is_default_namespace;
	iface->insert_before = (GXmlDomNode* (*)(GXmlDomNode*, GXmlDomNode*, GXmlDomNode*, GError**)) gxml_gom_node_real_insert_before;
	iface->append_child = (GXmlDomNode* (*)(GXmlDomNode*, GXmlDomNode*, GError**)) gxml_gom_node_real_append_child;
	iface->replace_child = (GXmlDomNode* (*)(GXmlDomNode*, GXmlDomNode*, GXmlDomNode*, GError**)) gxml_gom_node_real_replace_child;
	iface->remove_child = (GXmlDomNode* (*)(GXmlDomNode*, GXmlDomNode*, GError**)) gxml_gom_node_real_remove_child;
	iface->get_node_type = gxml_gom_node_real_get_node_type;
	iface->get_node_name = gxml_gom_node_real_get_node_name;
	iface->get_base_uri = gxml_gom_node_real_get_base_uri;
	iface->get_owner_document = gxml_gom_node_real_get_owner_document;
	iface->set_owner_document = gxml_gom_node_real_set_owner_document;
	iface->get_parent_node = gxml_gom_node_real_get_parent_node;
	iface->get_parent_element = gxml_gom_node_real_get_parent_element;
	iface->get_child_nodes = gxml_gom_node_real_get_child_nodes;
	iface->get_first_child = gxml_gom_node_real_get_first_child;
	iface->get_last_child = gxml_gom_node_real_get_last_child;
	iface->get_previous_sibling = gxml_gom_node_real_get_previous_sibling;
	iface->get_next_sibling = gxml_gom_node_real_get_next_sibling;
	iface->get_node_value = gxml_gom_node_real_get_node_value;
	iface->set_node_value = gxml_gom_node_real_set_node_value;
	iface->get_text_content = gxml_gom_node_real_get_text_content;
	iface->set_text_content = gxml_gom_node_real_set_text_content;
}


static void gxml_gom_node_instance_init (GXmlGomNode * self) {
}


static void gxml_gom_node_finalize (GObject* obj) {
	GXmlGomNode * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GXML_TYPE_GOM_NODE, GXmlGomNode);
	_g_free0 (self->_local_name);
	_g_free0 (self->_prefix);
	_g_free0 (self->_base_uri);
	_g_free0 (self->_node_value);
	_g_object_unref0 (self->_parent);
	_g_object_unref0 (self->_child_nodes);
	_g_object_unref0 (self->_document);
	G_OBJECT_CLASS (gxml_gom_node_parent_class)->finalize (obj);
}


GType gxml_gom_node_get_type (void) {
	static volatile gsize gxml_gom_node_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_gom_node_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlGomNodeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gxml_gom_node_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GXmlGomNode), 0, (GInstanceInitFunc) gxml_gom_node_instance_init, NULL };
		static const GInterfaceInfo gxml_dom_event_target_info = { (GInterfaceInitFunc) gxml_gom_node_gxml_dom_event_target_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo gxml_dom_node_info = { (GInterfaceInitFunc) gxml_gom_node_gxml_dom_node_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gxml_gom_node_type_id;
		gxml_gom_node_type_id = g_type_register_static (G_TYPE_OBJECT, "GXmlGomNode", &g_define_type_info, 0);
		g_type_add_interface_static (gxml_gom_node_type_id, GXML_TYPE_DOM_EVENT_TARGET, &gxml_dom_event_target_info);
		g_type_add_interface_static (gxml_gom_node_type_id, GXML_TYPE_DOM_NODE, &gxml_dom_node_info);
		g_once_init_leave (&gxml_gom_node_type_id__volatile, gxml_gom_node_type_id);
	}
	return gxml_gom_node_type_id__volatile;
}


static void _vala_gxml_gom_node_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GXmlGomNode * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GOM_NODE, GXmlGomNode);
	switch (property_id) {
		case GXML_GOM_NODE_NODE_TYPE:
		g_value_set_enum (value, gxml_dom_node_get_node_type ((GXmlDomNode*) self));
		break;
		case GXML_GOM_NODE_NODE_NAME:
		g_value_take_string (value, gxml_dom_node_get_node_name ((GXmlDomNode*) self));
		break;
		case GXML_GOM_NODE_BASE_URI:
		g_value_set_string (value, gxml_dom_node_get_base_uri ((GXmlDomNode*) self));
		break;
		case GXML_GOM_NODE_OWNER_DOCUMENT:
		g_value_set_object (value, gxml_dom_node_get_owner_document ((GXmlDomNode*) self));
		break;
		case GXML_GOM_NODE_PARENT_NODE:
		g_value_take_object (value, gxml_dom_node_get_parent_node ((GXmlDomNode*) self));
		break;
		case GXML_GOM_NODE_PARENT_ELEMENT:
		g_value_take_object (value, gxml_dom_node_get_parent_element ((GXmlDomNode*) self));
		break;
		case GXML_GOM_NODE_CHILD_NODES:
		g_value_take_object (value, gxml_dom_node_get_child_nodes ((GXmlDomNode*) self));
		break;
		case GXML_GOM_NODE_FIRST_CHILD:
		g_value_take_object (value, gxml_dom_node_get_first_child ((GXmlDomNode*) self));
		break;
		case GXML_GOM_NODE_LAST_CHILD:
		g_value_take_object (value, gxml_dom_node_get_last_child ((GXmlDomNode*) self));
		break;
		case GXML_GOM_NODE_PREVIOUS_SIBLING:
		g_value_take_object (value, gxml_dom_node_get_previous_sibling ((GXmlDomNode*) self));
		break;
		case GXML_GOM_NODE_NEXT_SIBLING:
		g_value_take_object (value, gxml_dom_node_get_next_sibling ((GXmlDomNode*) self));
		break;
		case GXML_GOM_NODE_NODE_VALUE:
		g_value_take_string (value, gxml_dom_node_get_node_value ((GXmlDomNode*) self));
		break;
		case GXML_GOM_NODE_TEXT_CONTENT:
		g_value_take_string (value, gxml_dom_node_get_text_content ((GXmlDomNode*) self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void _vala_gxml_gom_node_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	GXmlGomNode * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GOM_NODE, GXmlGomNode);
	switch (property_id) {
		case GXML_GOM_NODE_OWNER_DOCUMENT:
		gxml_dom_node_set_owner_document ((GXmlDomNode*) self, g_value_get_object (value));
		break;
		case GXML_GOM_NODE_NODE_VALUE:
		gxml_dom_node_set_node_value ((GXmlDomNode*) self, g_value_get_string (value));
		break;
		case GXML_GOM_NODE_TEXT_CONTENT:
		gxml_dom_node_set_text_content ((GXmlDomNode*) self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static GXmlDomNode* gxml_gom_node_list_real_item (GXmlDomNodeList* base, gint index) {
	GXmlGomNodeList * self;
	GXmlDomNode* result = NULL;
	gint _tmp0_ = 0;
	gpointer _tmp1_ = NULL;
	self = (GXmlGomNodeList*) base;
	_tmp0_ = index;
	_tmp1_ = GEE_ABSTRACT_LIST_CLASS (gxml_gom_node_list_parent_class)->get ((GeeAbstractList*) G_TYPE_CHECK_INSTANCE_CAST (self, GEE_TYPE_ARRAY_LIST, GeeArrayList), _tmp0_);
	result = (GXmlDomNode*) _tmp1_;
	return result;
}


GXmlGomNodeList* gxml_gom_node_list_construct (GType object_type) {
	GXmlGomNodeList * self = NULL;
	self = (GXmlGomNodeList*) gee_array_list_construct (object_type, GXML_TYPE_DOM_NODE, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
	return self;
}


GXmlGomNodeList* gxml_gom_node_list_new (void) {
	return gxml_gom_node_list_construct (GXML_TYPE_GOM_NODE_LIST);
}


static gint gxml_gom_node_list_real_get_length (GXmlDomNodeList* base) {
	gint result;
	GXmlGomNodeList* self;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	self = (GXmlGomNodeList*) base;
	_tmp0_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) self);
	_tmp1_ = _tmp0_;
	result = _tmp1_;
	return result;
}


static void gxml_gom_node_list_class_init (GXmlGomNodeListClass * klass) {
	gxml_gom_node_list_parent_class = g_type_class_peek_parent (klass);
	G_OBJECT_CLASS (klass)->get_property = _vala_gxml_gom_node_list_get_property;
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GOM_NODE_LIST_LENGTH, g_param_spec_int ("length", "length", "length", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
}


static void gxml_gom_node_list_gxml_dom_node_list_interface_init (GXmlDomNodeListIface * iface) {
	gxml_gom_node_list_gxml_dom_node_list_parent_iface = g_type_interface_peek_parent (iface);
	iface->item = (GXmlDomNode* (*)(GXmlDomNodeList*, gint)) gxml_gom_node_list_real_item;
	iface->get_length = gxml_gom_node_list_real_get_length;
}


static void gxml_gom_node_list_instance_init (GXmlGomNodeList * self) {
}


/**
 * List of {@link DomNode} implementing {@link DomNodeList}
 */
GType gxml_gom_node_list_get_type (void) {
	static volatile gsize gxml_gom_node_list_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_gom_node_list_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlGomNodeListClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gxml_gom_node_list_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GXmlGomNodeList), 0, (GInstanceInitFunc) gxml_gom_node_list_instance_init, NULL };
		static const GInterfaceInfo gxml_dom_node_list_info = { (GInterfaceInitFunc) gxml_gom_node_list_gxml_dom_node_list_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gxml_gom_node_list_type_id;
		gxml_gom_node_list_type_id = g_type_register_static (GEE_TYPE_ARRAY_LIST, "GXmlGomNodeList", &g_define_type_info, 0);
		g_type_add_interface_static (gxml_gom_node_list_type_id, GXML_TYPE_DOM_NODE_LIST, &gxml_dom_node_list_info);
		g_once_init_leave (&gxml_gom_node_list_type_id__volatile, gxml_gom_node_list_type_id);
	}
	return gxml_gom_node_list_type_id__volatile;
}


static void _vala_gxml_gom_node_list_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GXmlGomNodeList * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GOM_NODE_LIST, GXmlGomNodeList);
	switch (property_id) {
		case GXML_GOM_NODE_LIST_LENGTH:
		g_value_set_int (value, gxml_dom_node_list_get_length ((GXmlDomNodeList*) self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}



